--------------------------------------------------------------
-- dBatchProcess
--
-- ..
-- (C) 2014 re.dread
--------------------------------------------------------------

--[[ TODO:

]]--

require 'process_slicer'
require 'presets'
require 'file_container'

local TOOLTIPS = true
local tool_id = "dBatchProcess"
local tool_version = "0.1"
local dialog = nil
local vb = nil

-- File lsit to keep track of the created temp files and the sample buffer
-- associated with them.
local file_list = {}

-- sort table by name
local function compare(v1, v2)
  if string.lower(v1.name) < string.lower(v2.name) then 
    return true 
  end
end

table.sort(presets, compare)

-- create list for popup box
local popup_list = table.create()

for _, p in ipairs(presets) do
  popup_list:insert(p.name)
end

local opt = renoise.Document.create("ScriptingToolPreferences") {
  path = [[c:\Program Files (x86)\sox-14-4-1\]],
  cmd = [[sox in_file out_file silence 1 0.1 1% reverse silence 1 0.1 1% reverse]],
  
  -- 1 = instrument, 2 = samples
  delete_source = 1,
}

renoise.tool().preferences = opt

-- add menu entries
--[[
renoise.tool():add_menu_entry {
  name = "Instrument Box: Batch process ...",
  invoke = function() show_dialog(true) end
}
]]

renoise.tool():add_menu_entry {
  name = "Sample Editor: Batch process ...",
  invoke = function() show_dialog(true) end
}

renoise.tool():add_menu_entry {
  name = "Sample Navigator: Batch process ...",
  invoke = function() show_dialog(true) end
}

function quote(string)
  return ((os.platform() == "WINDOWS") and "\"" .. string .. "\"" or string)
end

function os.capture(cmd, raw)
  local f = assert(io.popen(cmd, 'r'))
  local s = assert(f:read('*a'))
  f:close()

  if raw then return s end
  s = string.gsub(s, '^%s+', '')
  s = string.gsub(s, '%s+$', '')
  s = string.gsub(s, '[\n\r]+', ' ')
  return s
end

local vol

function process_sample(sample, analyze)
  if not sample then return end

  local buffer = sample.sample_buffer
  
  if not buffer.has_sample_data then return end

  -- save sample to temp location
  local file_in = os.tmpname("wav")
  buffer:save_as(file_in, "wav")

  -- prepare output file
  local file_out = os.tmpname("wav")

  -- substitute sample paths
  local cmd = string.gsub(opt.cmd.value, "@in", quote(file_in))
  local cmd = string.gsub(cmd, "@out", quote(file_out))

  -- kind of dirty, but seems to work
  cmd = quote(opt.path.value) .. cmd .. " 2>&1 "

  print(cmd)

  -- execute command
  local cmd_output = os.capture(quote(cmd))
  
  rprint(cmd_output)

  local vol_find = string.find(cmd_output, "%d+%.%d+$")

  if vol_find then
    local vol_tmp = tonumber(string.sub(cmd_output, vol_find))

    if vol then
      vol = (vol_tmp < vol) and vol_tmp or vol
    else -- first sample
      vol = vol_tmp
    end
  end

  if vol then
    print("Sample volume: -" .. vol .."db")
  end

  -- store the sample
  local output_file = io.exists(file_out)
  
  if not output_file then
    renoise.app():show_status(
      analyze and "dBatchProcess: analyzing sample volumes" or
      "dBatchProcess: WARNING: No output file produced, loading input file .. ")
  end

  table.insert(file_list, 
    FileContainer:new {
      buffer = buffer,
      fin = file_in, 
      fout = file_out, 
      output_file = output_file 
    })

  -- buffer:load_from(output_file and file_out or file_in)
end

function update_progress(sample_i, samples)
  vb.views.process_all_btn.text = sample_i .. " / " .. samples
  
  if sample_i == samples then
    vb.views.process_all_btn.text = "Process all!"
  end
end

function process_all_()
  vol = nil
  local instr = renoise.song().selected_instrument
  local normalize = false

  if opt.cmd.value == "@normalize" then
    opt.cmd.value = "sox @in -n stat -v"
    normalize = true
  end

  for sample_i, sample in ipairs(instr.samples) do
    process_sample(sample, true)
    update_progress(sample_i, #instr.samples)
    coroutine:yield()
  end

  if normalize then
    opt.cmd.value = ("sox -v %f @in @out"):format(vol - 0.01)

    for sample_i, sample in ipairs(instr.samples) do
      process_sample(sample)
      update_progress(sample_i, #instr.samples)
      coroutine:yield()
    end

    opt.cmd.value = "@normalize"
  end
end

-- ----------------------------------------------------------------------------
-- Function called by ProcessSlicer after it stops processing.
-- 
-- It iterates through the file list and loads each new file to its associated 
-- sample buffer.
function on_finish()
  for i = 1, #file_list, 1 do
    local file_in = file_list[i].fin
    local file_out = file_list[i].fout
    local output_file = file_list[i].output_file
    local buffer = file_list[i].buffer
    
    buffer:load_from(output_file and file_out or file_in)
  end
end

local process

function process_all()
  -- Reset the list before processing.
  file_list = {}
  process = ProcessSlicer(process_all_, on_finish, update_progress)
  process:start()
  --process_all_(update_progress)
end

function cancel()
  if process and process:running() then
    process:stop()
  end
end

------------------------------
-- ze gui
------------------------------
function show_dialog(instr)
  if dialog and dialog.visible then
    dialog:show()
    return
  end

  vb = renoise.ViewBuilder()

  local DEFAULT_DIALOG_MARGIN =
    renoise.ViewBuilder.DEFAULT_DIALOG_MARGIN
  local DEFAULT_CONTROL_SPACING =
    renoise.ViewBuilder.DEFAULT_CONTROL_SPACING
  local DEFAULT_BUTTON_HEIGHT =
    renoise.ViewBuilder.DEFAULT_DIALOG_BUTTON_HEIGHT

  -- dialog content
  local dialog_content = vb:column {
    style = "body",
    margin = DEFAULT_DIALOG_MARGIN,
    spacing = DEFAULT_CONTROL_SPACING,
    uniform = true,

    vb:horizontal_aligner {
      --visible = false,
      mode = "justify",
      vb:text { text = "Process samples", font = "bold" },
    },

    vb:space { height = 5 },

    vb:row {
      style = "border",
      margin = DEFAULT_DIALOG_MARGIN,
      spacing = DEFAULT_CONTROL_SPACING,
      vb:column {
        vb:text { text = "PATH " },
        vb:text { text = "CMD " },
        vb:text { text = "Presets: " },
      },
      vb:column {
        spacing = DEFAULT_CONTROL_SPACING,
        vb:horizontal_aligner {
          mode = "justify",
          vb:textfield {
            id = "path_txt",
            bind = opt.path,
            width = 280,
          },
          vb:button {
          id = "select_path",
          text = "*",
          notifier = function()
            local new_path = renoise.app():prompt_for_path("Executable path ...")
            
            if new_path and new_path ~= "" then
              opt.path.value = new_path
            end
          end,
          },
        },
        vb:textfield {
          id = "cmd_txt",
          bind = opt.cmd,
          width = 300,
        },
        vb:popup {
          id = "pname",
          items = popup_list,
          width = 300,
          notifier = function(i)
            vb.views.desc_txt.text = presets[i].desc
            opt.cmd.value = presets[i].cmd
          end
        },
        vb:multiline_textfield {
          id = "desc_txt",
          width = 300,
          height = 55,
          text = presets[vb.views.pname.value].desc
        },
      },
    },

    --vb:space { height = 5 },

    vb:horizontal_aligner {
      visible = false,
      vb:checkbox {
        bind = opt.delete_source_sample
      },
      vb:text { text = " delete source sample(s)" },
    },

    --vb:space { height = 10 },

    vb:horizontal_aligner {
      mode = "distribute",
      spacing = DEFAULT_CONTROL_SPACING,
      margin = 5,
      vb:button {
        id = "process_btn",
        text = "Process sample!",
        notifier = function()
          process_sample(renoise.song().selected_sample)
        end
      },
      vb:button {
        id = "process_all_btn",
        text = "Process all!",
        notifier = process_all,
      },
      vb:button {
        text = "Cancel!",
        notifier = cancel,
      },
    },
  }

  -- key_handler
  local function key_handler(dialog, key)
    -- ignore held keys
    if (key.repeated) then
      return
    end

    if (key.name == "esc") then
      dialog:close()
    end
  end

  -- init dialog fields
  for i, p in ipairs(presets) do

    if (p.cmd == opt.cmd.value) then
      vb.views.pname.value = i
      vb.views.desc_txt.text = p.desc
      break;
    end
  end

  -- show
  dialog = renoise.app():show_custom_dialog(
    tool_id .. " " .. tool_version, dialog_content, key_handler)
end
