-- presets:
presets = {

  {
    name = "SoX: Normalize (Relative)",
    cmd = "@normalize",
    desc = [[Normalize all samples relative to the loudest sample.]],
  },
  
  {
    name = "SoX: Alpass",
    cmd = "sox @in @out allpass 2000 1",
    desc = [[Apply a two-pole all-pass filter with central frequency (in Hz) frequency, and filter-width width. An all-pass filter changes the audio’s frequency to phase relationship without changing its frequency to amplitude relationship. The filter is described in detail in [1]. This effect supports the −−plot global option.]],
  },
  
    {
    name = "SoX: Reverse",
    cmd = "sox @in @out reverse",
    desc = [[Reverse the audio completely. Requires temporary file space to store the audio to be reversed.]],
  },
  
      {
    name = "SoX: Riaa",
    cmd = "sox @in @out riaa",
    desc = [[Apply RIAA vinyl playback equalisation. The sampling rate must be one of: 44.1, 48, 88.2, 96 kHz. This effect supports the −−plot global option.]],
  },
  
        {
    name = "SoX: Noiseprof (where is this file saved?)",
    cmd = "sox @in @out noiseprof",
    desc = [[Calculate a profile of the audio for use in noise reduction. See the description of the noisered effect for details.]],
  },
  
         {
    name = "SoX: 8 BIT maker",
    cmd = "sox @in -b8 @out",
    desc = [[make it 8 bit]],
  },
  
	{
    name = "SoX: 8 BIT 22050 Hz maker",
    cmd = "sox @in -b 8 -r 22050 @out",
    desc = "[[Converts to 8-bit 22050 Hz.]]",
  }, 
  
        {
    name = "SoX: Convert to OKI-ADPCM",
    cmd = "sox @in -e oki-adpcm @out",
    desc = [[OKI (a.k.a. VOX, Dialogic, or Intel) 4-bit ADPCM; it has a precision equivalent to roughly 12-bit PCM. ADPCM is a form of audio compression that has a good compromise between audio quality and encoding/decoding speed.]],
  }, 
  
       {
    name = "SoX: Convert to IMA-ADPCM",
    cmd = "sox @in -e ima-adpcm @out",
    desc = [[IMA (a.k.a. DVI) 4-bit ADPCM; it has a precision equivalent to roughly 13-bit PCM.]],
  },
  
       {
    name = "SoX: Convert to A-LAW",
    cmd = "sox @in -e a-law @out",
    desc = [[International telephony standard for logarithmic encoding to 8 bits per sample. It has a precision equivalent to roughly 13-bit PCM and is sometimes encoded with reversed bit-ordering (see the −X option).]],
  },
  
     {
    name = "SoX: Convert to U-LAW",
    cmd = "sox @in -e u-law @out",
    desc = [[North American telephony standard for logarithmic encoding to 8 bits per sample. A.k.a. μ-law. It has a precision equivalent to roughly 14-bit PCM and is sometimes encoded with reversed bit-ordering (see the −X option).]],
  },
  
     {
    name = "SoX: Convert to MU-LAW",
    cmd = "sox @in -e mu-law @out",
    desc = [[North American telephony standard for logarithmic encoding to 8 bits per sample. A.k.a. μ-law. It has a precision equivalent to roughly 14-bit PCM and is sometimes encoded with reversed bit-ordering (see the −X option).]],
  },
  
     {
    name = "SoX: Convert to SIGNED-INTEGER",
    cmd = "sox @in -e signed-integer @out",
    desc = [[PCM data stored as signed (‘two’s complement’) integers. Commonly used with a 16 or 24 −bit encoding size. A value of 0 represents minimum signal power.]],
  },        
   
     {
    name = "SoX: Convert to UNSIGNED-INTEGER",
    cmd = "sox @in -e unsigned-integer @out",
    desc = [[PCM data stored as unsigned integers. Commonly used with an 8-bit encoding size. A value of 0 represents maximum signal power.]],
  },
  
      {
    name = "SoX: Convert to FLOATING-POINT",
    cmd = "sox @in -e floating-point @out",
    desc = [[PCM data stored as IEEE 753 single precision (32-bit) or double precision (64-bit) floating-point (‘real’) numbers. A value of 0 represents minimum signal power.]],
  },    
    
        {
    name = "SoX: Convert to MS-ADPCM",
    cmd = "sox @in -e ms-adpcm @out",
    desc = [[Microsoft 4-bit ADPCM; it has a precision equivalent to roughly 14-bit PCM.]],
  }, 
 
 
  
         {
    name = "SoX: Swap stereo channels",
    cmd = "sox @in @out swap",
    desc = [[Swap stereo channels. If the input is not stereo, pairs of channels are swapped, and a possible odd last channel passed through. E.g., for seven channels, the output order will be 2, 1, 4, 3, 6, 5, 7. See also remix for an effect that allows arbitrary channel selection and ordering (and mixing).]],
  },
  
          {
    name = "SoX: Stretch (shorten)",
    cmd = "sox @in @out stretch 0.6",
    desc = [[Change the audio duration (but not its pitch). This effect is broadly equivalent to the tempo effect with (factor inverted and) search set to zero, so in general, its results are comparatively poor; it is retained as it can sometimes out-perform tempo for small factors. factor of stretching: >1 lengthen, <1 shorten duration. window size is in ms. Default is 20ms. The fade option, can be ‘lin’. shift ratio, in [0 1]. Default depends on stretch factor. 1 to shorten, 0.8 to lengthen. The fading ratio, in [0 0.5]. The amount of a fade’s default depends on factor and shift. See also the tempo effect.]],
  },
  
          {
    name = "SoX: Stretch (lengthen)",
    cmd = "sox @in @out stretch 1.6",
    desc = [[Change the audio duration (but not its pitch). This effect is broadly equivalent to the tempo effect with (factor inverted and) search set to zero, so in general, its results are comparatively poor; it is retained as it can sometimes out-perform tempo for small factors. factor of stretching: >1 lengthen, <1 shorten duration. window size is in ms. Default is 20ms. The fade option, can be ‘lin’. shift ratio, in [0 1]. Default depends on stretch factor. 1 to shorten, 0.8 to lengthen. The fading ratio, in [0 0.5]. The amount of a fade’s default depends on factor and shift. See also the tempo effect.]],
  },
  
           {
    name = "SoX: Stretch (lengthen weird)",
    cmd = "sox @in @out stretch 2 1",
    desc = [[Change the audio duration (but not its pitch). This effect is broadly equivalent to the tempo effect with (factor inverted and) search set to zero, so in general, its results are comparatively poor; it is retained as it can sometimes out-perform tempo for small factors. factor of stretching: >1 lengthen, <1 shorten duration. window size is in ms. Default is 20ms. The fade option, can be ‘lin’. shift ratio, in [0 1]. Default depends on stretch factor. 1 to shorten, 0.8 to lengthen. The fading ratio, in [0 0.5]. The amount of a fade’s default depends on factor and shift. See also the tempo effect.]],
  },
  
             {
    name = "SoX: Synth brownnoise)",
    cmd = "sox @in @out synth brownnoise",
    desc = [[brownnoise]],
  },
  
               {
    name = "SoX: Synth karplus strong pluck)",
    cmd = "sox @in @out synth 4 pluck",
    desc = [[pluck]],
  },
  
              {
    name = "SoX: Ringmod the input 2",
    cmd = "sox @in @out synth 4 pluck fmod 700",
    desc = [[ringmod]],
  },
  
              {
    name = "SoX: Ringmod the input",
    cmd = "sox @in @out synth 2 sine fmod 444",
    desc = [[ringmod]],
  },
  
  
               {
    name = "SoX: Synth Submaker 50Hz sine",
    cmd = "sox @in @out synth 3 sine 50",
    desc = [[subby tones sine]],
  },
  
              {
    name = "SoX: Synth Submaker 50Hz square",
    cmd = "sox @in @out synth 3 square 50",
    desc = [[subby tones square]],
  },
  
              {
    name = "SoX: Synth Submaker 50Hz triangle",
    cmd = "sox @in @out synth 3 triangle 50",
    desc = [[subby tones triangle]],
  },
  
                {
    name = "SoX: Synth Submaker 50Hz sawtooth",
    cmd = "sox @in @out synth 3 sawtooth 50",
    desc = [[subby tones sawtooth]],
  },
  
                  {
    name = "SoX: Synth Submaker 50Hz trapezium",
    cmd = "sox @in @out synth 3 trapezium 50",
    desc = [[subby tones trapezium]],
  },
  
                    {
    name = "SoX: Synth Submaker 50Hz exp",
    cmd = "sox @in @out synth 3 exp 50",
    desc = [[subby tones exp]],
  },
  
                  {
    name = "SoX: Synth Whitenoise",
    cmd = "sox @in @out synth 3 whitenoise",
    desc = [[whitenoise]],
  },
  
                    {
    name = "SoX: Synth Tpdfnoise",
    cmd = "sox @in @out synth 3 tpdfnoise",
    desc = [[tpdfnoise]],
  },

                  {
    name = "SoX: Synth Pinknoise",
    cmd = "sox @in @out synth 3 pinknoise",
    desc = [[pinknoise]],
  },
        
                  {
    name = "SoX: Synth Squaresweep (low - high)",
    cmd = "sox @in @out synth 10 square 20/44100",
    desc = [[Squaresweep]],
  },  
  
                 {
    name = "SoX: Synth telephone",
    cmd = "sox @in @out synth 0.5 sine 200 synth sine fmod 700",
    desc = [[telephony]],
  },
  
                   {
    name = "SoX: Synth sweep (low - high)",
    cmd = "sox @in @out synth 3 sine 20-44100",
    desc = [[sweepy]],
  },
  
                     {
    name = "SoX: Synth sweep (high - low)",
    cmd = "sox @in @out synth 3 sine 44100-20",
    desc = [[sweepy revved]],
  },
  
                      {
    name = "SoX: Synth bleepje",
    cmd = "sox @in @out synth 4 square C2 sine C2 fade 0.001 3 2",
    desc = [[This effect can be used to generate fixed or swept frequency audio tones with various wave shapes, or to generate wide-band noise of various ‘colours’. Multiple synth effects can be cascaded to produce more complex waveforms; at each stage it is possible to choose whether the generated waveform will be mixed with, or modulated onto the output from the previous stage. Audio for each channel in a multi-channel audio file can be synthesised independently. Though this effect is used to generate audio, an input file must still be given, the characteristics of which will be used to set the synthesised audio length, the number of channels, and the sampling rate; however, since the input file’s audio is not normally needed, a ‘null file’ (with the special name −n) is often given instead (and the length specified as a parameter to synth or by another given effect that has an associated length). For example, the following produces a 3 second, 48kHz, audio file containing a sine-wave swept from 300 to 3300 Hz: sox −n output.wav synth 3 sine 300−3300 and this produces an 8 kHz version: sox −r 8000 −n output.wav synth 3 sine 300−3300 . Multiple channels can be synthesised by specifying the set of parameters shown between braces multiple times; the following puts the swept tone in the left channel and adds ‘brown’ noise in the right: sox −n output.wav synth 3 sine 300−3300 brownnoise . The following example shows how two synth effects can be cascaded to create a more complex waveform: play −n synth 0.5 sine 200−500 synth 0.5 sine fmod 700−100 . Frequencies can also be given in ‘scientific’ note notation, or, by prefixing a ‘%’ character, as a number of semitones relative to ‘middle A’ (440 Hz). For example, the following could be used to help tune a guitar’s low ‘E’ string: play −n synth 4 pluck %−29 or with a (Bourne shell) loop, the whole guitar: for n in E2 A2 D3 G3 B3 E4; do play −n synth 4 pluck $n repeat 2; done . See the delay effect (above) and the reference to ‘SoX scripting examples’ (below) for more synth examples. N.B. This effect generates audio at maximum volume (0dBFS), which means that there is a high chance of clipping when using the audio subsequently, so in many cases, you will want to follow this effect with the gain effect to prevent this from happening. (See also Clipping above.) Note that, by default, the synth effect incorporates the functionality of gain −h (see the gain effect for details); synth’s −n option may be given to disable this behaviour.

A detailed description of each synth parameter follows:

len is the length of audio to synthesise (any time specification); a value of 0 indicated to use the input length, which is also the default.

type is one of sine, square, triangle, sawtooth, trapezium, exp, [white]noise, tpdfnoise, pinknoise, brownnoise, pluck; default=sine.

combine is one of create, mix, amod (amplitude modulation), fmod (frequency modulation); default=create.

freq/freq2 are the frequencies at the beginning/end of synthesis in Hz or, if preceded with ‘%’, semitones relative to A (440 Hz); alternatively, ‘scientific’ note notation (e.g. E2) may be used. The default frequency is 440Hz. By default, the tuning used with the note notations is ‘equal temperament’; the −j KEY option selects ‘just intonation’, where KEY is an integer number of semitones relative to A (so for example, −9 or 3 selects the key of C), or a note in scientific notation.

If freq2 is given, then len must also have been given and the generated tone will be swept between the given frequencies. The two given frequencies must be separated by one of the characters ‘:’, ‘+’, ‘/’, or ‘−’. This character is used to specify the sweep function as follows:

: Linear: the tone will change by a fixed number of hertz per second.

+ Square: a second-order function is used to change the tone.

/ Exponential: the tone will change by a fixed number of semitones per second.

− Exponential: as ‘/’, but initial phase always zero, and stepped (less smooth) frequency changes.

 Not used for noise.

off is the bias (DC-offset) of the signal in percent; default=0.
ph is the phase shift in percentage of 1 cycle; default=0. Not used for noise.
p1 is the percentage of each cycle that is ‘on’ (square), or ‘rising’ (triangle, exp, trapezium); default=50 (square, triangle, exp), default=10 (trapezium), or sustain (pluck); default=40.
p2 (trapezium): the percentage through each cycle at which ‘falling’ begins; default=50. exp: the amplitude in multiples of 2dB; default=50, or tone-1 (pluck); default=20.
p3 (trapezium): the percentage through each cycle at which ‘falling’ ends; default=60, or tone-2 (pluck); default=90]],
  },
  
  
        {
    name = "SoX: Splice",
    cmd = "sox @in @out splice 0.4 0.5 1 1.2 3 4.5",
    desc = [[Splice together audio sections. This effect provides two things over simple audio concatenation: a (usually short) cross-fade is applied at the join, and a wave similarity comparison is made to help determine the best place at which to make the join. One of the options −h, −t, or −q may be given to select the fade envelope as half-cosine wave (the default), triangular (a.k.a. linear), or quarter-cosine wave respectively. To perform a splice, first use the trim effect to select the audio sections to be joined together. As when performing a tape splice, the end of the section to be spliced onto should be trimmed with a small excess (default 0.005 seconds) of audio after the ideal joining point. The beginning of the audio section to splice on should be trimmed with the same excess (before the ideal joining point), plus an additional leeway (default 0.005 seconds). Any time specification may be used for these parameters. SoX should then be invoked with the two audio sections as input files and the splice effect given with the position at which to perform the splice - this is length of the first audio section (including the excess).]],
  },
  
       {
    name = "SoX: Speed (up)",
    cmd = "sox @in @out speed 2",
    desc = [[Adjust the audio speed (pitch and tempo together). factor is either the ratio of the new speed to the old speed: greater than 1 speeds up, less than 1 slows down, or, if appended with the letter ‘c’, the number of cents (i.e. 100ths of a semitone) by which the pitch (and tempo) should be adjusted: greater than 0 increases, less than 0 decreases. Technically, the speed effect only changes the sample rate information, leaving the samples themselves untouched. The rate effect is invoked automatically to resample to the output sample rate, using its default quality/speed. For higher quality or higher speed resampling, in addition to the speed effect, specify the rate effect with the desired quality option.
See also the bend, pitch, and tempo effects.]],
  },
  
        {
    name = "SoX: Speed (down)",
    cmd = "sox @in @out speed 0.5",
    desc = [[Adjust the audio speed (pitch and tempo together). factor is either the ratio of the new speed to the old speed: greater than 1 speeds up, less than 1 slows down, or, if appended with the letter ‘c’, the number of cents (i.e. 100ths of a semitone) by which the pitch (and tempo) should be adjusted: greater than 0 increases, less than 0 decreases. Technically, the speed effect only changes the sample rate information, leaving the samples themselves untouched. The rate effect is invoked automatically to resample to the output sample rate, using its default quality/speed. For higher quality or higher speed resampling, in addition to the speed effect, specify the rate effect with the desired quality option.
See also the bend, pitch, and tempo effects.]],
  },
  
  
         {
    name = "SoX: Spectrogram (creates .png in dbatch tool folder)",
    cmd = "sox @in @out -n spectrogram",
    desc = [[Create a spectrogram of the audio; the audio is passed unmodified through the SoX processing chain. This effect is optional - type sox −−help and check the list of supported effects to see if it has been included. The spectrogram is rendered in a Portable Network Graphic (PNG) file, and shows time in the X-axis, frequency in the Y-axis, and audio signal magnitude in the Z-axis. Z-axis values are represented by the colour (or optionally the intensity) of the pixels in the X-Y plane. If the audio signal contains multiple channels then these are shown from top to bottom starting from channel 1 (which is the left channel for stereo audio). For example, if ‘my.wav’ is a stereo file, then with sox my.wav −n spectrogram a spectrogram of the entire file will be created in the file ‘spectrogram.png’. More often though, analysis of a smaller portion of the audio is required; e.g. with sox my.wav −n remix 2 trim 20 30 spectrogram the spectrogram shows information only from the second (right) channel, and of thirty seconds of audio starting from twenty seconds in. To analyse a small portion of the frequency domain, the rate effect may be used, e.g. sox my.wav −n rate 6k spectrogram allows detailed analysis of frequencies up to 3kHz (half the sampling rate) i.e. where the human auditory system is most sensitive. With sox my.wav −n trim 0 10 spectrogram −x 600 −y 200 −z 100 the given options control the size of the spectrogram’s X, Y & Z axes (in this case, the spectrogram area of the produced image will be 600 by 200 pixels in size and the Z-axis range will be 100 dB). Note that the produced image includes axes legends etc. and so will be a little larger than the specified spectrogram size. In this example: sox −n −n synth 6 tri 10k:14k spectrogram −z 100 −w kaiser an analysis ‘window’ with high dynamic range is selected to best display the spectrogram of a swept triangular wave. For a smilar example, append the following to the ‘chime’ command in the description of the delay effect (above): rate 2k spectrogram −X 200 −Z −10 −w kaiser Options are also available to control the appearance (colour-set, brightness, contrast, etc.) and filename of the spectrogram; e.g. with sox my.wav −n spectrogram −m −l −o print.png a spectrogram is created suitable for printing on a ‘black and white’ printer.

Options: 

−x num

Change the (maximum) width (X-axis) of the spectrogram from its default value of 800 pixels to a given number between 100 and 200000. See also −X and −d.

−X num

X-axis pixels/second; the default is auto-calculated to fit the given or known audio duration to the X-axis size, or 100 otherwise. If given in conjunction with −d, this option affects the width of the spectrogram; otherwise, it affects the duration of the spectrogram. num can be from 1 (low time resolution) to 5000 (high time resolution) and need not be an integer. SoX may make a slight adjustment to the given number for processing quantisation reasons; if so, SoX will report the actual number used (viewable when the SoX global option −V is in effect). See also −x and −d.

−y num

Sets the Y-axis size in pixels (per channel); this is the number of frequency ‘bins’ used in the Fourier analysis that produces the spectrogram. N.B. it can be slow to produce the spectrogram if this number is not one more than a power of two (e.g. 129). By default the Y-axis size is chosen automatically (depending on the number of channels). See −Y for alternative way of setting spectrogram height.

−Y num

Sets the target total height of the spectrogram(s). The default value is 550 pixels. Using this option (and by default), SoX will choose a height for individual spectrogram channels that is one more than a power of two, so the actual total height may fall short of the given number. However, there is also a minimum height per channel so if there are many channels, the number may be exceeded. See −y for alternative way of setting spectrogram height.

−z num

Z-axis (colour) range in dB, default 120. This sets the dynamic-range of the spectrogram to be −num dBFS to 0 dBFS. Num may range from 20 to 180. Decreasing dynamic-range effectively increases the ‘contrast’ of the spectrogram display, and vice versa.

−Z num

Sets the upper limit of the Z-axis in dBFS. A negative num effectively increases the ‘brightness’ of the spectrogram display, and vice versa.

−q num

Sets the Z-axis quantisation, i.e. the number of different colours (or intensities) in which to render Z-axis values. A small number (e.g. 4) will give a ‘poster’-like effect making it easier to discern magnitude bands of similar level. Small numbers also usually result in small PNG files. The number given specifies the number of colours to use inside the Z-axis range; two colours are reserved to represent out-of-range values.

−w name

Window: Hann (default), Hamming, Bartlett, Rectangular, Kaiser or Dolph. The spectrogram is produced using the Discrete Fourier Transform (DFT) algorithm. A significant parameter to this algorithm is the choice of ‘window function’. By default, SoX uses the Hann window which has good all-round frequency-resolution and dynamic-range properties. For better frequency resolution (but lower dynamic-range), select a Hamming window; for higher dynamic-range (but poorer frequency-resolution), select a Dolph window. Kaiser, Bartlett and Rectangular windows are also available.

−W num

Window adjustment parameter. This can be used to make small adjustments to the Kaiser or Dolph window shape. A positive number (up to ten) increases its dynamic range, a negative number decreases it.

−s

Allow slack overlapping of DFT windows. This can, in some cases, increase image sharpness and give greater adherence to the −x value, but at the expense of a little spectral loss.

−m

Creates a monochrome spectrogram (the default is colour).

−h

Selects a high-colour palette - less visually pleasing than the default colour palette, but it may make it easier to differentiate different levels. If this option is used in conjunction with −m, the result will be a hybrid monochrome/colour palette.

−p num

Permute the colours in a colour or hybrid palette. The num parameter, from 1 (the default) to 6, selects the permutation.

−l

Creates a ‘printer friendly’ spectrogram with a light background (the default has a dark background).

−a

Suppress the display of the axis lines. This is sometimes useful in helping to discern artefacts at the spectrogram edges.

−r

Raw spectrogram: suppress the display of axes and legends.

−A

Selects an alternative, fixed colour-set. This is provided only for compatibility with spectrograms produced by another package. It should not normally be used as it has some problems, not least, a lack of differentiation at the bottom end which results in masking of low-level artefacts.

−t text

Set the image title - text to display above the spectrogram.

−c text

Set (or clear) the image comment - text to display below and to the left of the spectrogram.

−o file

Name of the spectrogram output PNG file, default ‘spectrogram.png’. If ‘-’ is given, the spectrogram will be sent to standard output (stdout).

 Advanced Options:

In order to process a smaller section of audio without affecting other effects or the output signal (unlike when the trim effect is used), the following options may be used.
−d duration This option sets the X-axis resolution such that audio with the given duration (a time specification) fits the selected (or default) X-axis width. For example, sox input.mp3 output.wav −n spectrogram −d 1:00 stats creates a spectrogram showing the first minute of the audio, whilst the stats effect is applied to the entire audio signal.

See also −X for an alternative way of setting the X-axis resolution.

−S position(=)

Start the spectrogram at the given point in the audio stream. For example sox input.aiff output.wav spectrogram −S 1:00 creates a spectrogram showing all but the first minute of the audio (the output file, however, receives the entire audio stream). For the ability to perform off-line processing of spectral data, see the stat effect.]],
  },
  
          {
    name = "SoX: Sinc (highpass)",
    cmd = "sox @in @out sinc 3k",
    desc = [[Apply a sinc kaiser-windowed low-pass, high-pass, band-pass, or band-reject filter to the signal. The freqHP and freqLP parameters give the frequencies of the 6dB points of a high-pass and low-pass filter that may be invoked individually, or together. If both are given, then freqHP less than freqLP creates a band-pass filter, freqHP greater than freqLP creates a band-reject filter. For example, the invocations; sinc 3k, sinc -4k, sinc 3k-4k, sinc 4k-3k create a high-pass, low-pass, band-pass, and band-reject filter respectively. The default stop-band attenuation of 120dB can be overridden with −a; alternatively, the kaiser-window ‘beta’ parameter can be given directly with −b. The default transition band-width of 5% of the total band can be overridden with −t (and tbw in Hertz); alternatively, the number of filter taps can be given directly with −n. If both freqHP and freqLP are given, then a −t or −n option given to the left of the frequencies applies to both frequencies; one of these options given to the right of the frequencies applies only to freqLP. The −p, −M, −I, and −L options control the filter’s phase response; see the rate effect for details. This effect supports the −−plot global option.]],
  },
  
            {
    name = "SoX: Sinc (lowpass)",
    cmd = "sox @in @out sinc -4k",
    desc = [[Apply a sinc kaiser-windowed low-pass, high-pass, band-pass, or band-reject filter to the signal. The freqHP and freqLP parameters give the frequencies of the 6dB points of a high-pass and low-pass filter that may be invoked individually, or together. If both are given, then freqHP less than freqLP creates a band-pass filter, freqHP greater than freqLP creates a band-reject filter. For example, the invocations; sinc 3k, sinc -4k, sinc 3k-4k, sinc 4k-3k create a high-pass, low-pass, band-pass, and band-reject filter respectively. The default stop-band attenuation of 120dB can be overridden with −a; alternatively, the kaiser-window ‘beta’ parameter can be given directly with −b. The default transition band-width of 5% of the total band can be overridden with −t (and tbw in Hertz); alternatively, the number of filter taps can be given directly with −n. If both freqHP and freqLP are given, then a −t or −n option given to the left of the frequencies applies to both frequencies; one of these options given to the right of the frequencies applies only to freqLP. The −p, −M, −I, and −L options control the filter’s phase response; see the rate effect for details. This effect supports the −−plot global option.]],
  },
  
              {
    name = "SoX: Sinc (bandpass)",
    cmd = "sox @in @out sinc 3k-4k",
    desc = [[Apply a sinc kaiser-windowed low-pass, high-pass, band-pass, or band-reject filter to the signal. The freqHP and freqLP parameters give the frequencies of the 6dB points of a high-pass and low-pass filter that may be invoked individually, or together. If both are given, then freqHP less than freqLP creates a band-pass filter, freqHP greater than freqLP creates a band-reject filter. For example, the invocations; sinc 3k, sinc -4k, sinc 3k-4k, sinc 4k-3k create a high-pass, low-pass, band-pass, and band-reject filter respectively. The default stop-band attenuation of 120dB can be overridden with −a; alternatively, the kaiser-window ‘beta’ parameter can be given directly with −b. The default transition band-width of 5% of the total band can be overridden with −t (and tbw in Hertz); alternatively, the number of filter taps can be given directly with −n. If both freqHP and freqLP are given, then a −t or −n option given to the left of the frequencies applies to both frequencies; one of these options given to the right of the frequencies applies only to freqLP. The −p, −M, −I, and −L options control the filter’s phase response; see the rate effect for details. This effect supports the −−plot global option.]],
  },
  
              {
    name = "SoX: Sinc (bandreject)",
    cmd = "sox @in @out sinc 4k-3k",
    desc = [[Apply a sinc kaiser-windowed low-pass, high-pass, band-pass, or band-reject filter to the signal. The freqHP and freqLP parameters give the frequencies of the 6dB points of a high-pass and low-pass filter that may be invoked individually, or together. If both are given, then freqHP less than freqLP creates a band-pass filter, freqHP greater than freqLP creates a band-reject filter. For example, the invocations; sinc 3k, sinc -4k, sinc 3k-4k, sinc 4k-3k create a high-pass, low-pass, band-pass, and band-reject filter respectively. The default stop-band attenuation of 120dB can be overridden with −a; alternatively, the kaiser-window ‘beta’ parameter can be given directly with −b. The default transition band-width of 5% of the total band can be overridden with −t (and tbw in Hertz); alternatively, the number of filter taps can be given directly with −n. If both freqHP and freqLP are given, then a −t or −n option given to the left of the frequencies applies to both frequencies; one of these options given to the right of the frequencies applies only to freqLP. The −p, −M, −I, and −L options control the filter’s phase response; see the rate effect for details. This effect supports the −−plot global option.]],
  },
  
  
          {
    name = "SoX: Silence (remove silence from beginning)",
    cmd = "sox @in @out silence 1 5 2%",
    desc = [[Removes silence from the beginning, middle, or end of the audio. ‘Silence’ is determined by a specified threshold. The above-periods value is used to indicate if audio should be trimmed at the beginning of the audio. A value of zero indicates no silence should be trimmed from the beginning. When specifying a non-zero above-periods, it trims audio up until it finds non-silence. Normally, when trimming silence from beginning of audio the above-periods will be 1 but it can be increased to higher values to trim all audio up to a specific count of non-silence periods. For example, if you had an audio file with two songs that each contained 2 seconds of silence before the song, you could specify an above-period of 2 to strip out both silence periods and the first song. When above-periods is non-zero, you must also specify a duration and threshold. duration indicates the amount of time that non-silence must be detected before it stops trimming audio. By increasing the duration, burst of noise can be treated as silence and trimmed off. threshold is used to indicate what sample value you should treat as silence. For digital audio, a value of 0 may be fine but for audio recorded from analog, you may wish to increase the value to account for background noise. When optionally trimming silence from the end of the audio, you specify a below-periods count. In this case, below-period means to remove all audio after silence is detected. Normally, this will be a value 1 of but it can be increased to skip over periods of silence that are wanted. For example, if you have a song with 2 seconds of silence in the middle and 2 second at the end, you could set below-period to a value of 2 to skip over the silence in the middle of the audio. For below-periods, duration specifies a period of silence that must exist before audio is not copied any more. By specifying a higher duration, silence that is wanted can be left in the audio. For example, if you have a song with an expected 1 second of silence in the middle and 2 seconds of silence at the end, a duration of 2 seconds could be used to skip over the middle silence. Unfortunately, you must know the length of the silence at the end of your audio file to trim off silence reliably. A workaround is to use the silence effect in combination with the reverse effect. By first reversing the audio, you can use the above-periods to reliably trim all audio from what looks like the front of the file. Then reverse the file again to get back to normal. To remove silence from the middle of a file, specify a below-periods that is negative. This value is then treated as a positive value and is also used to indicate that the effect should restart processing as specified by the above-periods, making it suitable for removing periods of silence in the middle of the audio. The option −l indicates that below-periods duration length of audio should be left intact at the beginning of each period of silence. For example, if you want to remove long pauses between words but do not want to remove the pauses completely. duration is a time specification with the peculiarity that a bare number is interpreted as a sample count, not as a number of seconds. For specifying seconds, either use the t suffix (as in ‘2t’) or specify minutes, too (as in ‘0:02’). threshold numbers may be suffixed with d to indicate the value is in decibels, or % to indicate a percentage of maximum value of the sample value (0% specifies pure digital silence). The following example shows how this effect can be used to start a recording that does not contain the delay at the start which usually occurs between ‘pressing the record button’ and the start of the performance: rec parameters filename other-effects silence 1 5 2%]],
  },
  
        {
    name = "SoX: Remix (select above channel from stereo file)",
    cmd = "sox @in @out remix 1",
    desc = [[Select and mix input audio channels into output audio channels. Each output channel is specified, in turn, by a given out-spec: a list of contributing input channels and volume specifications. Note that this effect operates on the audio channels within the SoX effects processing chain; it should not be confused with the −m global option (where multiple files are mix-combined before entering the effects chain). An out-spec contains comma-separated input channel-numbers and hyphen-delimited channel-number ranges; alternatively, 0 may be given to create a silent output channel. For example, sox input.wav output.wav remix 6 7 8 0 creates an output file with four channels, where channels 1, 2, and 3 are copies of channels 6, 7, and 8 in the input file, and channel 4 is silent. Whereas sox input.wav output.wav remix 1−3,7 3 creates a (somewhat bizarre) stereo output file where the left channel is a mix-down of input channels 1, 2, 3, and 7, and the right channel is a copy of input channel 3. Where a range of channels is specified, the channel numbers to the left and right of the hyphen are optional and default to 1 and to the number of input channels respectively. Thus sox input.wav output.wav remix − performs a mix-down of all input channels to mono. By default, where an output channel is mixed from multiple (n) input channels, each input channel will be scaled by a factor of ¹/ n . Custom mixing volumes can be set by following a given input channel or range of input channels with a vol-spec (volume specification).]],
  },
  
          {
    name = "SoX: Remix (select below channel from stereo file)",
    cmd = "sox @in @out remix 2",
    desc = [[Select and mix input audio channels into output audio channels. Each output channel is specified, in turn, by a given out-spec: a list of contributing input channels and volume specifications. Note that this effect operates on the audio channels within the SoX effects processing chain; it should not be confused with the −m global option (where multiple files are mix-combined before entering the effects chain). An out-spec contains comma-separated input channel-numbers and hyphen-delimited channel-number ranges; alternatively, 0 may be given to create a silent output channel. For example, sox input.wav output.wav remix 6 7 8 0 creates an output file with four channels, where channels 1, 2, and 3 are copies of channels 6, 7, and 8 in the input file, and channel 4 is silent. Whereas sox input.wav output.wav remix 1−3,7 3 creates a (somewhat bizarre) stereo output file where the left channel is a mix-down of input channels 1, 2, 3, and 7, and the right channel is a copy of input channel 3. Where a range of channels is specified, the channel numbers to the left and right of the hyphen are optional and default to 1 and to the number of input channels respectively. Thus sox input.wav output.wav remix − performs a mix-down of all input channels to mono. By default, where an output channel is mixed from multiple (n) input channels, each input channel will be scaled by a factor of ¹/ n . Custom mixing volumes can be set by following a given input channel or range of input channels with a vol-spec (volume specification).]],
  },
  
            {
    name = "SoX: Remix (mixdown stereo to mono)",
    cmd = "sox @in @out remix 1-2",
    desc = [[Select and mix input audio channels into output audio channels. Each output channel is specified, in turn, by a given out-spec: a list of contributing input channels and volume specifications. Note that this effect operates on the audio channels within the SoX effects processing chain; it should not be confused with the −m global option (where multiple files are mix-combined before entering the effects chain). An out-spec contains comma-separated input channel-numbers and hyphen-delimited channel-number ranges; alternatively, 0 may be given to create a silent output channel. For example, sox input.wav output.wav remix 6 7 8 0 creates an output file with four channels, where channels 1, 2, and 3 are copies of channels 6, 7, and 8 in the input file, and channel 4 is silent. Whereas sox input.wav output.wav remix 1−3,7 3 creates a (somewhat bizarre) stereo output file where the left channel is a mix-down of input channels 1, 2, 3, and 7, and the right channel is a copy of input channel 3. Where a range of channels is specified, the channel numbers to the left and right of the hyphen are optional and default to 1 and to the number of input channels respectively. Thus sox input.wav output.wav remix − performs a mix-down of all input channels to mono. By default, where an output channel is mixed from multiple (n) input channels, each input channel will be scaled by a factor of ¹/ n . Custom mixing volumes can be set by following a given input channel or range of input channels with a vol-spec (volume specification).]],
  },
  
              {
    name = "SoX: Remix (mono oops a stereo file)",
    cmd = "sox @in @out remix 1,2i",
    desc = [[Select and mix input audio channels into output audio channels. Each output channel is specified, in turn, by a given out-spec: a list of contributing input channels and volume specifications. Note that this effect operates on the audio channels within the SoX effects processing chain; it should not be confused with the −m global option (where multiple files are mix-combined before entering the effects chain). An out-spec contains comma-separated input channel-numbers and hyphen-delimited channel-number ranges; alternatively, 0 may be given to create a silent output channel. For example, sox input.wav output.wav remix 6 7 8 0 creates an output file with four channels, where channels 1, 2, and 3 are copies of channels 6, 7, and 8 in the input file, and channel 4 is silent. Whereas sox input.wav output.wav remix 1−3,7 3 creates a (somewhat bizarre) stereo output file where the left channel is a mix-down of input channels 1, 2, 3, and 7, and the right channel is a copy of input channel 3. Where a range of channels is specified, the channel numbers to the left and right of the hyphen are optional and default to 1 and to the number of input channels respectively. Thus sox input.wav output.wav remix − performs a mix-down of all input channels to mono. By default, where an output channel is mixed from multiple (n) input channels, each input channel will be scaled by a factor of ¹/ n . Custom mixing volumes can be set by following a given input channel or range of input channels with a vol-spec (volume specification).]],
  },
  
                {
    name = "SoX: Remix (clear (& create) mono sample))",
    cmd = "sox @in @out remix 0",
    desc = [[Select and mix input audio channels into output audio channels. Each output channel is specified, in turn, by a given out-spec: a list of contributing input channels and volume specifications. Note that this effect operates on the audio channels within the SoX effects processing chain; it should not be confused with the −m global option (where multiple files are mix-combined before entering the effects chain). An out-spec contains comma-separated input channel-numbers and hyphen-delimited channel-number ranges; alternatively, 0 may be given to create a silent output channel. For example, sox input.wav output.wav remix 6 7 8 0 creates an output file with four channels, where channels 1, 2, and 3 are copies of channels 6, 7, and 8 in the input file, and channel 4 is silent. Whereas sox input.wav output.wav remix 1−3,7 3 creates a (somewhat bizarre) stereo output file where the left channel is a mix-down of input channels 1, 2, 3, and 7, and the right channel is a copy of input channel 3. Where a range of channels is specified, the channel numbers to the left and right of the hyphen are optional and default to 1 and to the number of input channels respectively. Thus sox input.wav output.wav remix − performs a mix-down of all input channels to mono. By default, where an output channel is mixed from multiple (n) input channels, each input channel will be scaled by a factor of ¹/ n . Custom mixing volumes can be set by following a given input channel or range of input channels with a vol-spec (volume specification).]],
  },
  
                  {
    name = "SoX: Remix (clear (& create) stereo sample))",
    cmd = "sox @in @out remix 0 0",
    desc = [[Select and mix input audio channels into output audio channels. Each output channel is specified, in turn, by a given out-spec: a list of contributing input channels and volume specifications. Note that this effect operates on the audio channels within the SoX effects processing chain; it should not be confused with the −m global option (where multiple files are mix-combined before entering the effects chain). An out-spec contains comma-separated input channel-numbers and hyphen-delimited channel-number ranges; alternatively, 0 may be given to create a silent output channel. For example, sox input.wav output.wav remix 6 7 8 0 creates an output file with four channels, where channels 1, 2, and 3 are copies of channels 6, 7, and 8 in the input file, and channel 4 is silent. Whereas sox input.wav output.wav remix 1−3,7 3 creates a (somewhat bizarre) stereo output file where the left channel is a mix-down of input channels 1, 2, 3, and 7, and the right channel is a copy of input channel 3. Where a range of channels is specified, the channel numbers to the left and right of the hyphen are optional and default to 1 and to the number of input channels respectively. Thus sox input.wav output.wav remix − performs a mix-down of all input channels to mono. By default, where an output channel is mixed from multiple (n) input channels, each input channel will be scaled by a factor of ¹/ n . Custom mixing volumes can be set by following a given input channel or range of input channels with a vol-spec (volume specification).]],
  },
  
          {
    name = "SoX: Noisered (how does this one work?)",
    cmd = "sox @in @out noisered 1 0.3",
    desc = [[Reduce noise in the audio signal by profiling and filtering. This effect is moderately effective at removing consistent background noise such as hiss or hum. To use it, first run SoX with the noiseprof effect on a section of audio that ideally would contain silence but in fact contains noise - such sections are typically found at the beginning or the end of a recording. noiseprof will write out a noise profile to profile-file, or to stdout if no profile-file or if ‘−’ is given. E.g. sox speech.wav −n trim 0 1.5 noiseprof speech.noise-profile. To actually remove the noise, run SoX again, this time with the noisered effect; noisered will reduce noise according to a noise profile (which was generated by noiseprof), from profile-file, or from stdin if no profile-file or if ‘−’ is given. E.g.sox speech.wav cleaned.wav noisered speech.noise-profile 0.3. How much noise should be removed is specified by amount-a number between 0 and 1 with a default of 0.5. Higher numbers will remove more noise but present a greater likelihood of removing wanted components of the audio signal. Before replacing an original recording with a noise-reduced version, experiment with different amount values to find the optimal one for your audio; use headphones to check that you are happy with the results, paying particular attention to quieter sections of the audio. On most systems, the two stages - profiling and reduction - can be combined using a pipe, e.g. sox noisy.wav −n trim 0 1 noiseprof | play noisy.wav noisered]],
  },
  
    {
    name = "SoX: Mcompand (doesn't work yet, preset syntax?",
    cmd = "sox @in @out mcompand 0.005,0.1 −47,−40,−34,−34,−17,−33 100",
    desc = [[The multi-band compander is similar to the single-band compander but the audio is first divided into bands using Linkwitz-Riley cross-over filters and a separately specifiable compander run on each band. See the compand effect for the definition of its parameters. Compand parameters are specified between double quotes and the crossover frequency for that band is given by crossover-freq; these can be repeated to create multiple bands.]],
  },
  
        {
    name = "SoX: Gain (+6)",
    cmd = "sox @in @out gain 6",
    desc = [[Apply amplification or attenuation to the audio signal, or, in some cases, to some of its channels. Note that use of any of −e, −B, −b, −r, or −n requires temporary file space to store the audio to be processed, so may be unsuitable for use with ‘streamed’ audio. Without other options, gain-dB is used to adjust the signal power level by the given number of dB: positive amplifies (beware of Clipping), negative attenuates. With other options, the gain-dB amplification or attenuation is (logically) applied after the processing due to those options. Given the −e option, the levels of the audio channels of a multi-channel file are ‘equalised’, i.e. gain is applied to all channels other than that with the highest peak level, such that all channels attain the same peak level (but, without also giving −n, the audio is not ‘normalised’). The −B (balance) option is similar to −e, but with −B, the RMS level is used instead of the peak level. −B might be used to correct stereo imbalance caused by an imperfect record turntable cartridge. Note that unlike −e, −B might cause some clipping. −b is similar to −B but has clipping protection, i.e. if necessary to prevent clipping whilst balancing, attenuation is applied to all channels. Note, however, that in conjunction with −n, −B and −b are synonymous. The −r option is used in conjunction with a prior invocation of gain with the −h option - see below for details. The −n option normalises the audio to 0dB FSD; it is often used in conjunction with a negative gain-dB to the effect that the audio is normalised to a given level below 0dB.]],
  },
  
         {
    name = "SoX: Gain (simple limiter: 6db gain never clip)",
    cmd = "sox @in @out gain -l 6",
    desc = [[Apply amplification or attenuation to the audio signal, or, in some cases, to some of its channels. Note that use of any of −e, −B, −b, −r, or −n requires temporary file space to store the audio to be processed, so may be unsuitable for use with ‘streamed’ audio. Without other options, gain-dB is used to adjust the signal power level by the given number of dB: positive amplifies (beware of Clipping), negative attenuates. With other options, the gain-dB amplification or attenuation is (logically) applied after the processing due to those options. Given the −e option, the levels of the audio channels of a multi-channel file are ‘equalised’, i.e. gain is applied to all channels other than that with the highest peak level, such that all channels attain the same peak level (but, without also giving −n, the audio is not ‘normalised’). The −B (balance) option is similar to −e, but with −B, the RMS level is used instead of the peak level. −B might be used to correct stereo imbalance caused by an imperfect record turntable cartridge. Note that unlike −e, −B might cause some clipping. −b is similar to −B but has clipping protection, i.e. if necessary to prevent clipping whilst balancing, attenuation is applied to all channels. Note, however, that in conjunction with −n, −B and −b are synonymous. The −r option is used in conjunction with a prior invocation of gain with the −h option - see below for details. The −n option normalises the audio to 0dB FSD; it is often used in conjunction with a negative gain-dB to the effect that the audio is normalised to a given level below 0dB.]],
  }, 
  
          {
    name = "SoX: Gain (-6)",
    cmd = "sox @in @out gain -6",
    desc = [[Apply amplification or attenuation to the audio signal, or, in some cases, to some of its channels. Note that use of any of −e, −B, −b, −r, or −n requires temporary file space to store the audio to be processed, so may be unsuitable for use with ‘streamed’ audio. Without other options, gain-dB is used to adjust the signal power level by the given number of dB: positive amplifies (beware of Clipping), negative attenuates. With other options, the gain-dB amplification or attenuation is (logically) applied after the processing due to those options. Given the −e option, the levels of the audio channels of a multi-channel file are ‘equalised’, i.e. gain is applied to all channels other than that with the highest peak level, such that all channels attain the same peak level (but, without also giving −n, the audio is not ‘normalised’). The −B (balance) option is similar to −e, but with −B, the RMS level is used instead of the peak level. −B might be used to correct stereo imbalance caused by an imperfect record turntable cartridge. Note that unlike −e, −B might cause some clipping. −b is similar to −B but has clipping protection, i.e. if necessary to prevent clipping whilst balancing, attenuation is applied to all channels. Note, however, that in conjunction with −n, −B and −b are synonymous. The −r option is used in conjunction with a prior invocation of gain with the −h option - see below for details. The −n option normalises the audio to 0dB FSD; it is often used in conjunction with a negative gain-dB to the effect that the audio is normalised to a given level below 0dB.]],
  },
  
       {
    name = "SoX: Fir (doesn't really work, needs coefs.txt",
    cmd = "sox @in @out fir 0.3 0.8 0.4 0.5",
    desc = [[Use SoX’s FFT convolution engine with given FIR filter coefficients. If a single argument is given then this is treated as the name of a file containing the filter coefficients (white-space separated; may contain ‘#’ comments). If the given filename is ‘−’, or if no argument is given, then the coefficients are read from the ‘standard input’ (stdin); otherwise, coefficients may be given on the command line.]],
  },
  
      {
    name = "SoX: Equalizer",
    cmd = "sox @in @out equalizer 1450 1 10",
    desc = [[Apply a two-pole peaking equalisation (EQ) filter. With this filter, the signal-level at and around a selected frequency can be increased or decreased, whilst (unlike band-pass and band-reject filters) that at all other frequencies is unchanged. frequency gives the filter’s central frequency in Hz, width, the band-width, and gain the required gain or attenuation in dB. Beware of Clipping when using a positive gain. In order to produce complex equalisation curves, this effect can be given several times, each with a different central frequency. The filter is described in detail in [1]. This effect supports the −−plot global option. See also bass and treble for shelving equalisation effects.]],
  },
  
    {
    name = "SoX: Repeat",
    cmd = "sox @in @out repeat 2",
    desc = [[Repeat the entire audio count times, or once if count is not given. The special value − requests infinite repetition. Requires temporary file space to store the audio to be repeated. Note that repeating once yields two copies: the original audio and the repeated audio.]],
  },
  
      {
    name = "SoX: Delay",
    cmd = "sox @in @out delay .05",
    desc = [[Delay one or more audio channels such that they start at the given position. For example, delay 1.5 +1 3000s delays the first channel by 1.5 seconds, the second channel by 2.5 seconds (one second more than the previous channel), the third channel by 3000 samples, and leaves any other channels that may be present un-delayed.]],
  },

     {
    name = "SoX: Delay (more severe)",
    cmd = "sox @in @out delay 1",
    desc = [[Delay one or more audio channels such that they start at the given position. For example, delay 1.5 +1 3000s delays the first channel by 1.5 seconds, the second channel by 2.5 seconds (one second more than the previous channel), the third channel by 3000 samples, and leaves any other channels that may be present un-delayed.]],
  },
  
        {
    name = "SoX: Dither",
    cmd = "sox @in @out dither",
    desc = [[Apply dithering to the audio. Dithering deliberately adds a small amount of noise to the signal in order to mask audible quantization effects that can occur if the output sample size is less than 24 bits. With no options, this effect will add triangular (TPDF) white noise. Noise-shaping (only for certain sample rates) can be selected with −s. With the −f option, it is possible to select a particular noise-shaping filter from the following list: lipshitz, f-weighted, modified-e-weighted, improved-e-weighted, gesemann, shibata, low-shibata, high-shibata. Note that most filter types are available only with 44100Hz sample rate. The filter types are distinguished by the following properties: audibility of noise, level of (inaudible, but in some circumstances, otherwise problematic) shaped high frequency noise, and processing speed.
See http://sox.sourceforge.net/SoX/NoiseShaping for graphs of the different noise-shaping curves. The −S option selects a slightly ‘sloped’ TPDF, biased towards higher frequencies. It can be used at any sampling rate but below ≈22k, plain TPDF is probably better, and above ≈ 37k, noise-shaping (if available) is probably better. The −a option enables a mode where dithering (and noise-shaping if applicable) are automatically enabled only when needed. The most likely use for this is when applying fade in or out to an already dithered file, so that the redithering applies only to the faded portions. However, auto dithering is not fool-proof, so the fades should be carefully checked for any noise modulation; if this occurs, then either re-dither the whole file, or use trim, fade, and concatencate. The −p option allows overriding the target precision. If the SoX global option −R option is not given, then the pseudo-random number generator used to generate the white noise will be ‘reseeded’, i.e. the generated noise will be different between invocations. This effect should not be followed by any other effect that affects the audio. See also the ‘Dithering’ section above.]],
  },
  
    {
    name = "SoX: Band",
    cmd = "sox @in @out band 1000 144",
    desc = [[Apply a band-pass filter. The frequency response drops logarithmically around the center frequency. The width parameter gives the slope of the drop. The frequencies at center + width and center − width will be half of their original amplitudes. band defaults to a mode oriented to pitched audio, i.e. voice, singing, or instrumental music. The −n (for noise) option uses the alternate mode for un-pitched audio (e.g. percussion). Warning: −n introduces a power-gain of about 11dB in the filter, so beware of output clipping. band introduces noise in the shape of the filter, i.e. peaking at the center frequency and settling around it. This effect supports the −−plot global option. See also sinc for a bandpass filter with steeper shoulders.]],
  },
  
      {
    name = "SoX: Bandreject",
    cmd = "sox @in @out bandreject 3400 14",
    desc = [[Apply a two-pole Butterworth band-pass or band-reject filter with central frequency frequency, and (3dB-point) band-width width. The −c option applies only to bandpass and selects a constant skirt gain (peak gain = Q) instead of the default: constant 0dB peak gain. The filters roll off at 6dB per octave (20dB per decade) and are described in detail in [1].
These effects support the −−plot global option. See also sinc for a bandpass filter with steeper shoulders.]],
  },

   {
    name = "SoX: Bandpass",
    cmd = "sox @in @out bandpass 2600 144",
    desc = [[Apply a two-pole Butterworth band-pass or band-reject filter with central frequency frequency, and (3dB-point) band-width width. The −c option applies only to bandpass and selects a constant skirt gain (peak gain = Q) instead of the default: constant 0dB peak gain. The filters roll off at 6dB per octave (20dB per decade) and are described in detail in [1].
These effects support the −−plot global option. See also sinc for a bandpass filter with steeper shoulders..]],
  },
  
     {
    name = "SoX: Bend (upwards)",
    cmd = "sox @in @out bend .35,180,.25",
    desc = [[Changes pitch by specified amounts at specified times. Each given triple: start-position,cents,end-position specifies one bend. cents is the number of cents (100 cents = 1 semitone) by which to bend the pitch. The other values specify the points in time at which to start and end bending the pitch, respectively. The pitch-bending algorithm utilises the Discrete Fourier Transform (DFT) at a particular frame rate and over-sampling rate. The −f and −o parameters may be used to adjust these parameters and thus control the smoothness of the changes in pitch.]],
  },
  
  
      {
    name = "SoX: Bend 2 (upwards moar extreme)",
    cmd = "sox @in @out bend .35,800,.25",
    desc = [[Changes pitch by specified amounts at specified times. Each given triple: start-position,cents,end-position specifies one bend. cents is the number of cents (100 cents = 1 semitone) by which to bend the pitch. The other values specify the points in time at which to start and end bending the pitch, respectively. The pitch-bending algorithm utilises the Discrete Fourier Transform (DFT) at a particular frame rate and over-sampling rate. The −f and −o parameters may be used to adjust these parameters and thus control the smoothness of the changes in pitch.]],
  },
  
       {
    name = "SoX: Bend 2 (downwards moar extreme)",
    cmd = "sox @in @out bend .35,-1000,.25",
    desc = [[Changes pitch by specified amounts at specified times. Each given triple: start-position,cents,end-position specifies one bend. cents is the number of cents (100 cents = 1 semitone) by which to bend the pitch. The other values specify the points in time at which to start and end bending the pitch, respectively. The pitch-bending algorithm utilises the Discrete Fourier Transform (DFT) at a particular frame rate and over-sampling rate. The −f and −o parameters may be used to adjust these parameters and thus control the smoothness of the changes in pitch.]],
  }, 
  
      {
    name = "SoX: Biquad (preset needs better coefficients)",
    cmd = "sox @in @out biquad 3 0.3 2 4 2 3",
    desc = [[Apply a biquad IIR filter with the given coefficients. Where b* and a* are the numerator and denominator coefficients respectively. See http://en.wikipedia.org/wiki/Digital_biquad_filter (where a0 = 1). This effect supports the −−plot global option.]],
  },
  
        {
    name = "SoX: Channels (mono mix)",
    cmd = "sox @in @out channels 1",
    desc = [[Invoke a simple algorithm to change the number of channels in the audio signal to the given number CHANNELS: mixing if decreasing the number of channels or duplicating if increasing the number of channels. The channels effect is invoked automatically if SoX’s −c option specifies a number of channels that is different to that of the input file(s). Alternatively, if this effect is given explicitly, then SoX’s −c option need not be given. ]],
  },
  
          {
    name = "SoX: Channels (make stereo)",
    cmd = "sox @in @out channels 2",
    desc = [[Invoke a simple algorithm to change the number of channels in the audio signal to the given number CHANNELS: mixing if decreasing the number of channels or duplicating if increasing the number of channels. The channels effect is invoked automatically if SoX’s −c option specifies a number of channels that is different to that of the input file(s). Alternatively, if this effect is given explicitly, then SoX’s −c option need not be given. ]],
  },
  
            {
    name = "SoX: Dc shift",
    cmd = "sox @in @out dcshift 0.2 1",
    desc = [[Apply a DC shift to the audio. This can be useful to remove a DC offset (caused perhaps by a hardware problem in the recording chain) from the audio. The effect of a DC offset is reduced headroom and hence volume. The stat or stats effect can be used to determine if a signal has a DC offset. The given dcshift value is a floating point number in the range of ±2 that indicates the amount to shift the audio (which is in the range of ±1). An optional limitergain can be specified as well. It should have a value much less than 1 (e.g. 0.05 or 0.02) and is used only on peaks to prevent clipping.]],
  },
  
              {
    name = "SoX: Deemph",
    cmd = "sox @in @out deemph",
    desc = [[Apply Compact Disc (IEC 60908) de-emphasis (a treble attenuation shelving filter). Pre-emphasis was applied in the mastering of some CDs issued in the early 1980s. These included many classical music albums, as well as now sought-after issues of albums by The Beatles, Pink Floyd and others. Pre-emphasis should be removed at playback time by a de-emphasis filter in the playback device. However, not all modern CD players have this filter, and very few PC CD drives have it; playing pre-emphasised audio without the correct de-emphasis filter results in audio that sounds harsh and is far from what its creators intended. With the deemph effect, it is possible to apply the necessary de-emphasis to audio that has been extracted from a pre-emphasised CD, and then either burn the de-emphasised audio to a new CD (which will then play correctly on any CD player), or simply play the correctly de-emphasised audio files on the PC.]],
  },
  
            {
    name = "SoX: Compand (preset doesn't work, I don't get the syntax)",
    cmd = "sox @in @out compand 0.3,1 6:−70,−60,−20 −5 −90 0.2",
    desc = [[Compand (compress or expand) the dynamic range of the audio. The attack and decay parameters (in seconds) determine the time over which the instantaneous level of the input signal is averaged to determine its volume; attacks refer to increases in volume and decays refer to decreases. For most situations, the attack time (response to the music getting louder) should be shorter than the decay time because the human ear is more sensitive to sudden loud music than sudden soft music. Where more than one pair of attack/decay parameters are specified, each input channel is companded separately and the number of pairs must agree with the number of input channels. Typical values are 0.3,0.8 seconds. The second parameter is a list of points on the compander’s transfer function specified in dB relative to the maximum possible signal amplitude. The input values must be in a strictly increasing order but the transfer function does not have to be monotonically rising. If omitted, the value of out-dB1 defaults to the same value as in-dB1; levels below in-dB1 are not companded (but may have gain applied to them). The point 0,0 is assumed but may be overridden (by 0,out-dBn). If the list is preceded by a soft-knee-dB value, then the points at where adjacent line segments on the transfer function meet will be rounded by the amount given. Typical values for the transfer function are 6:−70,−60,−20. The third (optional) parameter is an additional gain in dB to be applied at all points on the transfer function and allows easy adjustment of the overall gain. The fourth (optional) parameter is an initial level to be assumed for each channel when companding starts. This permits the user to supply a nominal level initially, so that, for example, a very large gain is not applied to initial signal levels before the companding action has begun to operate: it is quite probable that in such an event, the output would be severely clipped while the compander gain properly adjusts itself. A typical value (for audio which is initially quiet) is −90 dB. The fifth (optional) parameter is a delay in seconds. The input signal is analysed immediately to control the compander, but it is delayed before being fed to the volume adjuster. Specifying a delay approximately equal to the attack/decay times allows the compander to effectively operate in a ‘predictive’ rather than a reactive mode. A typical value is 0.2 seconds.]],
  },
  
            {
    name = "SoX: Chorus",
    cmd = "sox @in @out chorus 0.7 0.9 55 0.4 0.25 2 -t",
    desc = [[Add a chorus effect to the audio. This can make a single vocal sound like a chorus, but can also be applied to instrumentation. Chorus resembles an echo effect with a short delay, but whereas with echo the delay is constant, with chorus, it is varied using sinusoidal or triangular modulation. The modulation depth defines the range the modulated delay is played before or after the delay. Hence the delayed sound will sound slower or faster, that is the delayed sound tuned around the original one, like in a chorus where some vocals are slightly off key. See [3] for more discussion of the chorus effect. Each four-tuple parameter delay/decay/speed/depth gives the delay in milliseconds and the decay (relative to gain-in) with a modulation speed in Hz using depth in milliseconds. The modulation is either sinusoidal (−s) or triangular (−t). Gain-out is the volume of the output. A typical delay is around 40ms to 60ms; the modulation speed is best near 0.25Hz and the modulation depth around 2ms.]],
  },
  
               {
    name = "SoX: Chorus 1",
    cmd = "sox @in @out chorus 0.8 0.7 20 0.4 3 6 -s",
    desc = [[Add a chorus effect to the audio. This can make a single vocal sound like a chorus, but can also be applied to instrumentation. Chorus resembles an echo effect with a short delay, but whereas with echo the delay is constant, with chorus, it is varied using sinusoidal or triangular modulation. The modulation depth defines the range the modulated delay is played before or after the delay. Hence the delayed sound will sound slower or faster, that is the delayed sound tuned around the original one, like in a chorus where some vocals are slightly off key. See [3] for more discussion of the chorus effect. Each four-tuple parameter delay/decay/speed/depth gives the delay in milliseconds and the decay (relative to gain-in) with a modulation speed in Hz using depth in milliseconds. The modulation is either sinusoidal (−s) or triangular (−t). Gain-out is the volume of the output. A typical delay is around 40ms to 60ms; the modulation speed is best near 0.25Hz and the modulation depth around 2ms.]],
  }, 
  
              {
    name = "SoX: Chorus 2",
    cmd = "sox @in @out chorus 0.8 0.6 99 0.6 0.2 10 -t",
    desc = [[Add a chorus effect to the audio. This can make a single vocal sound like a chorus, but can also be applied to instrumentation. Chorus resembles an echo effect with a short delay, but whereas with echo the delay is constant, with chorus, it is varied using sinusoidal or triangular modulation. The modulation depth defines the range the modulated delay is played before or after the delay. Hence the delayed sound will sound slower or faster, that is the delayed sound tuned around the original one, like in a chorus where some vocals are slightly off key. See [3] for more discussion of the chorus effect. Each four-tuple parameter delay/decay/speed/depth gives the delay in milliseconds and the decay (relative to gain-in) with a modulation speed in Hz using depth in milliseconds. The modulation is either sinusoidal (−s) or triangular (−t). Gain-out is the volume of the output. A typical delay is around 40ms to 60ms; the modulation speed is best near 0.25Hz and the modulation depth around 2ms.]],
  },

  {
    name = "SoX: Bass (Boost)",
    cmd = "sox @in @out bass 10 80",
    desc = [[Boost or cut the bass (lower) or treble (upper) frequencies of the audio using a two-pole shelving filter with a response similar to that of a standard hi-fi’s tone-controls. This is also known as shelving equalisation (EQ). gain gives the gain at 0 Hz (for bass), or whichever is the lower of ∼22 kHz and the Nyquist frequency (for treble). Its useful range is about −20 (for a large cut) to +20 (for a large boost). Beware of Clipping when using a positive gain. If desired, the filter can be fine-tuned using the following optional parameters: frequency sets the filter’s central frequency and so can be used to extend or reduce the frequency range to be boosted or cut. The default value is 100 Hz (for bass) or 3 kHz (for treble). width determines how steep is the filter’s shelf transition. In addition to the common width specification methods described above, ‘slope’ (the default, or if appended with ‘s’) may be used. The useful range of ‘slope’ is about 0.3, for a gentle slope, to 1 (the maximum), for a steep slope; the default value is 0.5.
The filters are described in detail in [1]. These effects support the −−plot global option. See also equalizer for a peaking equalisation effect.]],
  },
  
   {
    name = "SoX: Bass (Cut)",
    cmd = "sox @in @out bass -10 80",
    desc = [[Boost or cut the bass (lower) or treble (upper) frequencies of the audio using a two-pole shelving filter with a response similar to that of a standard hi-fi’s tone-controls. This is also known as shelving equalisation (EQ). gain gives the gain at 0 Hz (for bass), or whichever is the lower of ∼22 kHz and the Nyquist frequency (for treble). Its useful range is about −20 (for a large cut) to +20 (for a large boost). Beware of Clipping when using a positive gain. If desired, the filter can be fine-tuned using the following optional parameters: frequency sets the filter’s central frequency and so can be used to extend or reduce the frequency range to be boosted or cut. The default value is 100 Hz (for bass) or 3 kHz (for treble). width determines how steep is the filter’s shelf transition. In addition to the common width specification methods described above, ‘slope’ (the default, or if appended with ‘s’) may be used. The useful range of ‘slope’ is about 0.3, for a gentle slope, to 1 (the maximum), for a steep slope; the default value is 0.5.
The filters are described in detail in [1]. These effects support the −−plot global option. See also equalizer for a peaking equalisation effect.]],
  }, 
  
    {
    name = "SoX: Treble",
    cmd = "sox @in @out treble 5 2666",
    desc = [[Boost or cut the bass (lower) or treble (upper) frequencies of the audio using a two-pole shelving filter with a response similar to that of a standard hi-fi’s tone-controls. This is also known as shelving equalisation (EQ). gain gives the gain at 0 Hz (for bass), or whichever is the lower of ∼22 kHz and the Nyquist frequency (for treble). Its useful range is about −20 (for a large cut) to +20 (for a large boost). Beware of Clipping when using a positive gain. If desired, the filter can be fine-tuned using the following optional parameters: frequency sets the filter’s central frequency and so can be used to extend or reduce the frequency range to be boosted or cut. The default value is 100 Hz (for bass) or 3 kHz (for treble). width determines how steep is the filter’s shelf transition. In addition to the common width specification methods described above, ‘slope’ (the default, or if appended with ‘s’) may be used. The useful range of ‘slope’ is about 0.3, for a gentle slope, to 1 (the maximum), for a steep slope; the default value is 0.5.
The filters are described in detail in [1]. These effects support the −−plot global option. See also equalizer for a peaking equalisation effect.]],
  },

  {
    name = "SoX: Trim silence (start/end)",
    cmd = "sox @in @out silence 1 0.1 0.1% reverse silence 1 0.1 0.1% reverse",
    desc = [[Trim silence from start and end of the sample.
    0.1% is the threshold value.]],
  },

  {
    name = "SoX: Change sample speed",
    cmd = "sox @in @out speed 1200c",
    desc = [[Speeds up the sample with an amount of cents, setting it to 1200 is like shifting the octave.]],
  },

  {
    name = "SoX: Contrast",
    cmd = "sox @in @out contrast 50",
    desc = [[Comparable with compression, this effect modifies an audio signal to make it sound louder. enhancement-amount controls the amount of the enhancement and is a number in the range 0−100. Note that enhancement-amount = 0 still gives a significant contrast enhancement.]],
  },

  {
    name = "SoX: Change sampling rate",
    cmd = "sox @in -r 22k @out",
    desc = [[Change the sampleing rate. Here 22k]],
  },

  {
    name = "SoX: Echo (Short metallic)",
    cmd = [[sox @in @out echo 0.8 0.88 6 0.4]],
    desc = [[echo gain-in gain-out <delay decay>
Add echoing to the audio. Echoes are reflected sound and can occur naturally amongst mountains (and sometimes large buildings) when talking or shouting; digital echo effects emulate this behaviour and are often used to help fill out the sound of a single instrument or vocal. The time difference between the original signal and the reflection is the ‘delay’ (time), and the loudness of the reflected signal is the ‘decay’. Multiple echoes can have different delays and decays.]],
  },
  
    {
    name = "SoX: Echo (longer delay)",
    cmd = [[sox @in @out echo 0.8 0.9 1000 0.3]],
    desc = [[echo gain-in gain-out <delay decay>
Add echoing to the audio. Echoes are reflected sound and can occur naturally amongst mountains (and sometimes large buildings) when talking or shouting; digital echo effects emulate this behaviour and are often used to help fill out the sound of a single instrument or vocal. The time difference between the original signal and the reflection is the ‘delay’ (time), and the loudness of the reflected signal is the ‘decay’. Multiple echoes can have different delays and decays.]],
  },
  
      {
    name = "SoX: Echo (longer delay 2)",
    cmd = [[sox @in @out echo 0.8 0.9 1000 0.3 1800 0.25]],
    desc = [[echo gain-in gain-out <delay decay>
Add echoing to the audio. Echoes are reflected sound and can occur naturally amongst mountains (and sometimes large buildings) when talking or shouting; digital echo effects emulate this behaviour and are often used to help fill out the sound of a single instrument or vocal. The time difference between the original signal and the reflection is the ‘delay’ (time), and the loudness of the reflected signal is the ‘decay’. Multiple echoes can have different delays and decays.]],
  },
  
        {
    name = "SoX: Echos (bounced twice in symmetric echos)",
    cmd = [[sox @in @out echos 0.8 0.7 700 0.25 700 0.3]],
    desc = [[gain-in gain-out <delay decay> Add a sequence of echoes to the audio. Each delay decay pair gives the delay in milliseconds and the decay (relative to gain-in) of that echo. Gain-out is the volume of the output. Like the echo effect, echos stand for ‘ECHO in Sequel’, that is the first echos takes the input, the second the input and the first echos, the third the input and the first and the second echos, ... and so on. Care should be taken using many echos; a single echos has the same effect as a single echo.]],
  },
  
          {
    name = "SoX: Echos (bounced twice in asymmetric echos)",
    cmd = [[sox @in @out echo 0.8 0.7 700 0.25 900 0.3]],
    desc = [[gain-in gain-out <delay decay> Add a sequence of echoes to the audio. Each delay decay pair gives the delay in milliseconds and the decay (relative to gain-in) of that echo. Gain-out is the volume of the output. Like the echo effect, echos stand for ‘ECHO in Sequel’, that is the first echos takes the input, the second the input and the first echos, the third the input and the first and the second echos, ... and so on. Care should be taken using many echos; a single echos has the same effect as a single echo.]],
  },
  
            {
    name = "SoX: Echos (as if in a garage)",
    cmd = [[sox @in @out echos 0.8 0.7 40 0.25 63 0.3]],
    desc = [[gain-in gain-out <delay decay> Add a sequence of echoes to the audio. Each delay decay pair gives the delay in milliseconds and the decay (relative to gain-in) of that echo. Gain-out is the volume of the output. Like the echo effect, echos stand for ‘ECHO in Sequel’, that is the first echos takes the input, the second the input and the first echos, the third the input and the first and the second echos, ... and so on. Care should be taken using many echos; a single echos has the same effect as a single echo.]],
  },
  
              {
    name = "SoX: Flanger",
    cmd = [[sox @in @out flanger 0.4 10 20 50]],
    desc = [[delay depth regen width speed shape phase interp. Apply a flanging effect to the audio. See [3] for a detailed description of flanging. All parameters are optional (right to left).]],
  },
  
                {
    name = "SoX: Highpass",
    cmd = [[sox @in @out highpass 2000]],
    desc = [[Apply a high-pass filter with 3dB point frequency. The filter can be either single-pole (with −1), or double-pole (the default, or with −2). width applies only to double-pole filters; the default is Q = 0.707 and gives a Butterworth response. The filters roll off at 6dB per pole per octave (20dB per pole per decade). The double-pole filters are described in detail in [1]. These effects support the −−plot global option. See also sinc for filters with a steeper roll-off.]],
  },
  
                  {
    name = "SoX: Lowpass",
    cmd = [[sox @in @out lowpass 100]],
    desc = [[Apply a low-pass filter with 3dB point frequency. The filter can be either single-pole (with −1), or double-pole (the default, or with −2). width applies only to double-pole filters; the default is Q = 0.707 and gives a Butterworth response. The filters roll off at 6dB per pole per octave (20dB per pole per decade). The double-pole filters are described in detail in [1]. These effects support the −−plot global option. See also sinc for filters with a steeper roll-off.]],
  },
  
                  {
    name = "SoX: loudness",
    cmd = [[sox @in @out loudness 2]],
    desc = [[Loudness control - similar to the gain effect, but provides equalisation for the human auditory system. See http://en.wikipedia.org/wiki/Loudness for a detailed description of loudness. The gain is adjusted by the given gain parameter (usually negative) and the signal equalised according to ISO 226 w.r.t. a reference level of 65dB, though an alternative reference level may be given if the original audio has been equalised for some other optimal level. A default gain of −10dB is used if a gain value is not given. See also the gain effect.]],
  },
 
               {
    name = "SoX: Hilbert",
    cmd = [[sox @in @out hilbert]],
    desc = [[Apply an odd-tap Hilbert transform filter, phase-shifting the signal by 90 degrees. This is used in many matrix coding schemes and for analytic signal generation. The process is often written as a multiplication by i (or j), the imaginary unit. An odd-tap Hilbert transform filter has a bandpass characteristic, attenuating the lowest and highest frequencies. Its bandwidth can be controlled by the number of filter taps, which can be specified with −n. By default, the number of taps is chosen for a cutoff frequency of about 75 Hz. This effect supports the −−plot global option.]],
  },
  
                {
    name = "SoX: Oops (only works on stereo samples)",
    cmd = [[sox @in @out oops]],
    desc = [[Out Of Phase Stereo effect. Mixes stereo to twin-mono where each mono channel contains the difference between the left and right stereo channels. This is sometimes known as the ‘karaoke’ effect as it often has the effect of removing most or all of the vocals from a recording. It is equivalent to remix 1,2i 1,2i.]],
  },

              {
    name = "SoX: Overdrive",
    cmd = [[sox @in @out overdrive 2]],
    desc = [[Non linear distortion. The colour parameter controls the amount of even harmonic content in the over-driven output.]],
  },
  
                {
    name = "SoX: Pad (insert silence)",
    cmd = [[sox @in @out pad 1.5 1]],
    desc = [[Pad the audio with silence, at the beginning, the end, or any specified points through the audio. length is the amount of silence to insert and position the position in the input audio stream at which to insert it. Any number of lengths and positions may be specified, provided that a specified position is not less that the previous one, and any time specification may be used for them. position is optional for the first and last lengths specified and if omitted correspond to the beginning and the end of the audio respectively. For example, pad 1.5 1.5 adds 1.5 seconds of silence padding at each end of the audio, whilst pad 4000s@3:00 inserts 4000 samples of silence 3 minutes into the audio. If silence is wanted only at the end of the audio, specify either the end position or specify a zero-length pad at the start. See also delay for an effect that can add silence at the beginning of the audio on a channel-by-channel basis.]],
  },
  
               {
    name = "SoX: Phaser",
    cmd = [[sox @in @out phaser 0.8 0.74 3 0.4 0.5]],
    desc = [[Add a phasing effect to the audio. See [3] for a detailed description of phasing. delay/decay/speed gives the delay in milliseconds and the decay (relative to gain-in) with a modulation speed in Hz. The modulation is either sinusoidal (−s) - preferable for multiple instruments, or triangular (−t) - gives single instruments a sharper phasing effect. The decay should be less than 0.5 to avoid feedback, and usually no less than 0.1. Gain-out is the volume of the output.]],
  },
  
                 {
    name = "SoX: Phaser 2",
    cmd = [[sox @in @out phaser 0.89 0.85 1 0.24 2]],
    desc = [[Add a phasing effect to the audio. See [3] for a detailed description of phasing. delay/decay/speed gives the delay in milliseconds and the decay (relative to gain-in) with a modulation speed in Hz. The modulation is either sinusoidal (−s) - preferable for multiple instruments, or triangular (−t) - gives single instruments a sharper phasing effect. The decay should be less than 0.5 to avoid feedback, and usually no less than 0.1. Gain-out is the volume of the output.]],
  },
  
                   {
    name = "SoX: Phaser 3 (more severe)",
    cmd = [[sox @in @out phaser 0.6 0.66 3 0.6 2]],
    desc = [[Add a phasing effect to the audio. See [3] for a detailed description of phasing. delay/decay/speed gives the delay in milliseconds and the decay (relative to gain-in) with a modulation speed in Hz. The modulation is either sinusoidal (−s) - preferable for multiple instruments, or triangular (−t) - gives single instruments a sharper phasing effect. The decay should be less than 0.5 to avoid feedback, and usually no less than 0.1. Gain-out is the volume of the output.]],
  },


              {
    name = "SoX: Pitch (up)",
    cmd = [[sox @in @out pitch 1200]],
    desc = [[Change the audio pitch (but not tempo). shift gives the pitch shift as positive or negative ‘cents’ (i.e. 100ths of a semitone). See the tempo effect for a description of the other parameters. See also the bend, speed, and tempo effects.]],
  },
  
                {
    name = "SoX: Pitch (down)",
    cmd = [[sox @in @out pitch -1200]],
    desc = [[Change the audio pitch (but not tempo). shift gives the pitch shift as positive or negative ‘cents’ (i.e. 100ths of a semitone). See the tempo effect for a description of the other parameters. See also the bend, speed, and tempo effects.]],
  },


  {
    name = "SoX: Fade in/out",
    cmd = [[sox @in @out fade 0.01 0 0.01]],
    desc = [[fade [type] fade-in-length [stop-time [fade-out-length]\]

Apply a fade effect to the beginning, end, or both of the audio. An optional type can be specified to select the shape of the fade curve: q for quarter of a sine wave, h for half a sine wave, t for linear (‘triangular’) slope, l for logarithmic, and p for inverted parabola. The default is logarithmic. A fade-in starts from the first sample and ramps the signal level from 0 to full volume over fade-in-length seconds. Specify 0 seconds if no fade-in is wanted. For fade-outs, the audio will be truncated at stop-time and the signal level will be ramped from full volume down to 0 starting at fade-out-length seconds before the stop-time. If fade-out-length is not specified, it defaults to the same value as fade-in-length. No fade-out is performed if stop-time is not specified. If the file length can be determined from the input file header and length-changing effects are not in effect, then 0 may be specified for stop-time to indicate the usual case of a fade-out that ends at the end of the input audio stream. All times can be specified in either periods of time or sample counts. To specify time periods use the format hh:mm:ss.frac format. To specify using sample counts, specify the number of samples and append the letter ‘s’ to the sample count (for example ‘8000s’).]],
  },
  
  {
    name = "SoX: Fade in (1 second)",
    cmd = [[sox @in @out fade h 1]],
    desc = [[fade [type] fade-in-length [stop-time [fade-out-length]\]

Apply a fade effect to the beginning, end, or both of the audio. An optional type can be specified to select the shape of the fade curve: q for quarter of a sine wave, h for half a sine wave, t for linear (‘triangular’) slope, l for logarithmic, and p for inverted parabola. The default is logarithmic. A fade-in starts from the first sample and ramps the signal level from 0 to full volume over fade-in-length seconds. Specify 0 seconds if no fade-in is wanted. For fade-outs, the audio will be truncated at stop-time and the signal level will be ramped from full volume down to 0 starting at fade-out-length seconds before the stop-time. If fade-out-length is not specified, it defaults to the same value as fade-in-length. No fade-out is performed if stop-time is not specified. If the file length can be determined from the input file header and length-changing effects are not in effect, then 0 may be specified for stop-time to indicate the usual case of a fade-out that ends at the end of the input audio stream. All times can be specified in either periods of time or sample counts. To specify time periods use the format hh:mm:ss.frac format. To specify using sample counts, specify the number of samples and append the letter ‘s’ to the sample count (for example ‘8000s’).]],
  },
  
  {
    name = "SoX: Fade out plucks (1 second)",
    cmd = [[sox @in @out fade 0 1 1]],
    desc = [[fade [type] fade-in-length [stop-time [fade-out-length]\]

Apply a fade effect to the beginning, end, or both of the audio. An optional type can be specified to select the shape of the fade curve: q for quarter of a sine wave, h for half a sine wave, t for linear (‘triangular’) slope, l for logarithmic, and p for inverted parabola. The default is logarithmic. A fade-in starts from the first sample and ramps the signal level from 0 to full volume over fade-in-length seconds. Specify 0 seconds if no fade-in is wanted. For fade-outs, the audio will be truncated at stop-time and the signal level will be ramped from full volume down to 0 starting at fade-out-length seconds before the stop-time. If fade-out-length is not specified, it defaults to the same value as fade-in-length. No fade-out is performed if stop-time is not specified. If the file length can be determined from the input file header and length-changing effects are not in effect, then 0 may be specified for stop-time to indicate the usual case of a fade-out that ends at the end of the input audio stream. All times can be specified in either periods of time or sample counts. To specify time periods use the format hh:mm:ss.frac format. To specify using sample counts, specify the number of samples and append the letter ‘s’ to the sample count (for example ‘8000s’).]],
  },      

  {
    name = "SoX: Normalize",
    cmd = [[sox @in @out norm 0.01]],
    desc = [[norm [dB-level]
Normalise the audio. norm is just an alias for gain −n; see the gain effect for details.]],
  },

  {
    name = "SoX: Reverb",
    cmd = [[sox @in @out pad 0 3 reverb]],
    desc = [[reverb [−w|−−wet-only] [reverberance (50%) [HF-damping (50%)
[room-scale (100%) [stereo-depth (100%)
[pre-delay (0ms) [wet-gain (0dB)]\]\]\]\]\]

Add reverberation to the audio using the ‘freeverb’ algorithm. A reverberation effect is sometimes desirable for concert halls that are too small or contain so many people that the hall’s natural reverberance is diminished. Applying a small amount of stereo reverb to a (dry) mono signal will usually make it sound more natural. See [3] for a detailed description of reverberation.]],
  },

  {
    name = "SoX: Downsample",
    cmd = [[sox @in @out downsample 3]],
    desc = [[Downsample the signal by an integer factor: Only the first out of each factor samples is retained, the others are discarded. No decimation filter is applied. If the input is not a properly bandlimited baseband signal, aliasing will occur. This may be desirable, e.g., for frequency translation. For a general resampling effect with anti-aliasing, see rate. See also upsample..]],
  },
  
  {
    name = "SoX: Upsample",
    cmd = [[sox @in @out upsample 2]],
    desc = [[Upsample the signal by an integer factor: factor−1 zero-value samples are inserted between each pair of input samples. As a result, the original spectrum is replicated into the new frequency space (imaging) and attenuated. This attenuation can be compensated for by adding vol factor after any further processing. The upsample effect is typically used in combination with filtering effects. For a general resampling effect with anti-imaging, see rate. See also downsample.]],
  },  
  
{
    name = "SoX: Tremolo 1 (fast)",
    cmd = [[sox @in @out tremolo 440 50]],
    desc = [[Apply a tremolo (low frequency amplitude modulation) effect to the audio. The tremolo frequency in Hz is given by speed, and the depth as a percentage by depth (default 40).]],
  },

{
    name = "SoX: Tremolo 0 (slow)",
    cmd = [[sox @in @out tremolo 4 80]],
    desc = [[Apply a tremolo (low frequency amplitude modulation) effect to the audio. The tremolo frequency in Hz is given by speed, and the depth as a percentage by depth (default 40).]],
  },

{
    name = "SoX: Tempo (speed up)",
    cmd = [[sox @in @out tempo 1.5]],
    desc = [[Change the audio playback speed but not its pitch. This effect uses the WSOLA algorithm. The audio is chopped up into segments which are then shifted in the time domain and overlapped (cross-faded) at points where their waveforms are most similar as determined by measurement of ‘least squares’. By default, linear searches are used to find the best overlapping points. If the optional −q parameter is given, tree searches are used instead. This makes the effect work more quickly, but the result may not sound as good. However, if you must improve the processing speed, this generally reduces the sound quality less than reducing the search or overlap values. The −m option is used to optimize default values of segment, search and overlap for music processing. The −s option is used to optimize default values of segment, search and overlap for speech processing. The −l option is used to optimize default values of segment, search and overlap for ‘linear’ processing that tends to cause more noticeable distortion but may be useful when factor is close to 1. If −m, −s, or −l is specified, the default value of segment will be calculated based on factor, while default search and overlap values are based on segment. Any values you provide still override these default values factor gives the ratio of new tempo to the old tempo, so e.g. 1.1 speeds up the tempo by 10%, and 0.9 slows it down by 10%. The optional segment parameter selects the algorithm’s segment size in milliseconds. If no other flags are specified, the default value is 82 and is typically suited to making small changes to the tempo of music. For larger changes (e.g. a factor of 2), 41 ms may give a better result. The −m, −s, and −l flags will cause the segment default to be automatically adjusted based on factor. For example using −s (for speech) with a tempo of 1.25 will calculate a default segment value of 32. The optional search parameter gives the audio length in milliseconds over which the algorithm will search for overlapping points. If no other flags are specified, the default value is 14.68. Larger values use more processing time and may or may not produce better results. A practical maximum is half the value of segment. Search can be reduced to cut processing time at the risk of degrading output quality. The −m, −s, and −l flags will cause the search default to be automatically adjusted based on segment. The optional overlap parameter gives the segment overlap length in milliseconds. Default value is 12, but −m, −s, or −l flags automatically adjust overlap based on segment size. Increasing overlap increases processing time and may increase quality. A practical maximum for overlap is the value of search, with overlap typically being (at least) a little smaller then search. See also speed for an effect that changes tempo and pitch together, pitch and bend for effects that change pitch only, and stretch for an effect that changes tempo using a different algorithm.]],
  },

{
    name = "SoX: Tempo 1 (speed down)",
    cmd = [[sox @in @out tempo 0.5]],
    desc = [[Change the audio playback speed but not its pitch. This effect uses the WSOLA algorithm. The audio is chopped up into segments which are then shifted in the time domain and overlapped (cross-faded) at points where their waveforms are most similar as determined by measurement of ‘least squares’. By default, linear searches are used to find the best overlapping points. If the optional −q parameter is given, tree searches are used instead. This makes the effect work more quickly, but the result may not sound as good. However, if you must improve the processing speed, this generally reduces the sound quality less than reducing the search or overlap values. The −m option is used to optimize default values of segment, search and overlap for music processing. The −s option is used to optimize default values of segment, search and overlap for speech processing. The −l option is used to optimize default values of segment, search and overlap for ‘linear’ processing that tends to cause more noticeable distortion but may be useful when factor is close to 1. If −m, −s, or −l is specified, the default value of segment will be calculated based on factor, while default search and overlap values are based on segment. Any values you provide still override these default values factor gives the ratio of new tempo to the old tempo, so e.g. 1.1 speeds up the tempo by 10%, and 0.9 slows it down by 10%. The optional segment parameter selects the algorithm’s segment size in milliseconds. If no other flags are specified, the default value is 82 and is typically suited to making small changes to the tempo of music. For larger changes (e.g. a factor of 2), 41 ms may give a better result. The −m, −s, and −l flags will cause the segment default to be automatically adjusted based on factor. For example using −s (for speech) with a tempo of 1.25 will calculate a default segment value of 32. The optional search parameter gives the audio length in milliseconds over which the algorithm will search for overlapping points. If no other flags are specified, the default value is 14.68. Larger values use more processing time and may or may not produce better results. A practical maximum is half the value of segment. Search can be reduced to cut processing time at the risk of degrading output quality. The −m, −s, and −l flags will cause the search default to be automatically adjusted based on segment. The optional overlap parameter gives the segment overlap length in milliseconds. Default value is 12, but −m, −s, or −l flags automatically adjust overlap based on segment size. Increasing overlap increases processing time and may increase quality. A practical maximum for overlap is the value of search, with overlap typically being (at least) a little smaller then search. See also speed for an effect that changes tempo and pitch together, pitch and bend for effects that change pitch only, and stretch for an effect that changes tempo using a different algorithm.]],
  },
   
{
    name = "SoX: Tempo 2 (speed down music)",
    cmd = [[sox @in @out tempo -m 0.5 41]],
    desc = [[Change the audio playback speed but not its pitch. This effect uses the WSOLA algorithm. The audio is chopped up into segments which are then shifted in the time domain and overlapped (cross-faded) at points where their waveforms are most similar as determined by measurement of ‘least squares’. By default, linear searches are used to find the best overlapping points. If the optional −q parameter is given, tree searches are used instead. This makes the effect work more quickly, but the result may not sound as good. However, if you must improve the processing speed, this generally reduces the sound quality less than reducing the search or overlap values. The −m option is used to optimize default values of segment, search and overlap for music processing. The −s option is used to optimize default values of segment, search and overlap for speech processing. The −l option is used to optimize default values of segment, search and overlap for ‘linear’ processing that tends to cause more noticeable distortion but may be useful when factor is close to 1. If −m, −s, or −l is specified, the default value of segment will be calculated based on factor, while default search and overlap values are based on segment. Any values you provide still override these default values factor gives the ratio of new tempo to the old tempo, so e.g. 1.1 speeds up the tempo by 10%, and 0.9 slows it down by 10%. The optional segment parameter selects the algorithm’s segment size in milliseconds. If no other flags are specified, the default value is 82 and is typically suited to making small changes to the tempo of music. For larger changes (e.g. a factor of 2), 41 ms may give a better result. The −m, −s, and −l flags will cause the segment default to be automatically adjusted based on factor. For example using −s (for speech) with a tempo of 1.25 will calculate a default segment value of 32. The optional search parameter gives the audio length in milliseconds over which the algorithm will search for overlapping points. If no other flags are specified, the default value is 14.68. Larger values use more processing time and may or may not produce better results. A practical maximum is half the value of segment. Search can be reduced to cut processing time at the risk of degrading output quality. The −m, −s, and −l flags will cause the search default to be automatically adjusted based on segment. The optional overlap parameter gives the segment overlap length in milliseconds. Default value is 12, but −m, −s, or −l flags automatically adjust overlap based on segment size. Increasing overlap increases processing time and may increase quality. A practical maximum for overlap is the value of search, with overlap typically being (at least) a little smaller then search. See also speed for an effect that changes tempo and pitch together, pitch and bend for effects that change pitch only, and stretch for an effect that changes tempo using a different algorithm.]],
  },
  
 {
    name = "SoX: Tempo 3 (speed down speech)",
    cmd = [[sox @in @out tempo -s 0.5 41]],
    desc = [[Change the audio playback speed but not its pitch. This effect uses the WSOLA algorithm. The audio is chopped up into segments which are then shifted in the time domain and overlapped (cross-faded) at points where their waveforms are most similar as determined by measurement of ‘least squares’. By default, linear searches are used to find the best overlapping points. If the optional −q parameter is given, tree searches are used instead. This makes the effect work more quickly, but the result may not sound as good. However, if you must improve the processing speed, this generally reduces the sound quality less than reducing the search or overlap values. The −m option is used to optimize default values of segment, search and overlap for music processing. The −s option is used to optimize default values of segment, search and overlap for speech processing. The −l option is used to optimize default values of segment, search and overlap for ‘linear’ processing that tends to cause more noticeable distortion but may be useful when factor is close to 1. If −m, −s, or −l is specified, the default value of segment will be calculated based on factor, while default search and overlap values are based on segment. Any values you provide still override these default values factor gives the ratio of new tempo to the old tempo, so e.g. 1.1 speeds up the tempo by 10%, and 0.9 slows it down by 10%. The optional segment parameter selects the algorithm’s segment size in milliseconds. If no other flags are specified, the default value is 82 and is typically suited to making small changes to the tempo of music. For larger changes (e.g. a factor of 2), 41 ms may give a better result. The −m, −s, and −l flags will cause the segment default to be automatically adjusted based on factor. For example using −s (for speech) with a tempo of 1.25 will calculate a default segment value of 32. The optional search parameter gives the audio length in milliseconds over which the algorithm will search for overlapping points. If no other flags are specified, the default value is 14.68. Larger values use more processing time and may or may not produce better results. A practical maximum is half the value of segment. Search can be reduced to cut processing time at the risk of degrading output quality. The −m, −s, and −l flags will cause the search default to be automatically adjusted based on segment. The optional overlap parameter gives the segment overlap length in milliseconds. Default value is 12, but −m, −s, or −l flags automatically adjust overlap based on segment size. Increasing overlap increases processing time and may increase quality. A practical maximum for overlap is the value of search, with overlap typically being (at least) a little smaller then search. See also speed for an effect that changes tempo and pitch together, pitch and bend for effects that change pitch only, and stretch for an effect that changes tempo using a different algorithm.]],
  },
       
      
  
 {
    name = "SoX: Tremolo 2 (faster)",
    cmd = [[sox @in @out tremolo 1000 70]],
    desc = [[Apply a tremolo (low frequency amplitude modulation) effect to the audio. The tremolo frequency in Hz is given by speed, and the depth as a percentage by depth (default 40).]],
  },         
  
   {
    name = "SoX: Vad (trim beginning silence from vocals)",
    cmd = [[sox @in @out norm vad]],
    desc = [[Voice Activity Detector. Attempts to trim silence and quiet background sounds from the ends of (fairly high resolution i.e. 16-bit, 44−48kHz) recordings of speech. The algorithm currently uses a simple cepstral power measurement to detect voice, so may be fooled by other things, especially music. The effect can trim only from the front of the audio, so in order to trim from the back, the reverse effect must also be used. E.g. play speech.wav norm vad to trim from the front, play speech.wav norm reverse vad reverse to trim from the back, and play speech.wav norm vad reverse vad reverse to trim from both ends. The use of the norm effect is recommended, but remember that neither reverse nor norm is suitable for use with streamed audio.

Options:
Default values are shown in parenthesis.
−t num (7)

The measurement level used to trigger activity detection. This might need to be changed depending on the noise level, signal level and other charactistics of the input audio.

−T num (0.25)

The time constant (in seconds) used to help ignore short bursts of sound.

−s num (1)

The amount of audio (in seconds) to search for quieter/shorter bursts of audio to include prior to the detected trigger point.

−g num (0.25)

Allowed gap (in seconds) between quieter/shorter bursts of audio to include prior to the detected trigger point.

−p num (0)

The amount of audio (in seconds) to preserve before the trigger point and any found quieter/shorter bursts.

Advanced Options:

These allow fine tuning of the algorithm’s internal parameters.

−b num

The algorithm (internally) uses adaptive noise estimation/reduction in order to detect the start of the wanted audio. This option sets the time for the initial noise estimate.

−N num

Time constant used by the adaptive noise estimator for when the noise level is increasing.

−n num

Time constant used by the adaptive noise estimator for when the noise level is decreasing.

−r num

Amount of noise reduction to use in the detection algorithm (e.g. 0, 0.5, ...).

−f num

Frequency of the algorithm’s processing/measurements.

−m num

Measurement duration; by default, twice the measurement period; i.e. with overlap.

−M num

Time constant used to smooth spectral measurements.

−h num

‘Brick-wall’ frequency of high-pass filter applied at the input to the detector algorithm.

−l num

‘Brick-wall’ frequency of low-pass filter applied at the input to the detector algorithm.

−H num

‘Brick-wall’ frequency of high-pass lifter used in the detector algorithm.

−L num

‘Brick-wall’ frequency of low-pass lifter used in the detector algorithm.

See also the silence effect..]],
  },
  
 {
    name = "SoX: Vad (trim beginning & end silence from vocals)",
    cmd = [[sox @in @out norm vad reverse vad reverse]],
    desc = [[Voice Activity Detector. Attempts to trim silence and quiet background sounds from the ends of (fairly high resolution i.e. 16-bit, 44−48kHz) recordings of speech. The algorithm currently uses a simple cepstral power measurement to detect voice, so may be fooled by other things, especially music. The effect can trim only from the front of the audio, so in order to trim from the back, the reverse effect must also be used. E.g. play speech.wav norm vad to trim from the front, play speech.wav norm reverse vad reverse to trim from the back, and play speech.wav norm vad reverse vad reverse to trim from both ends. The use of the norm effect is recommended, but remember that neither reverse nor norm is suitable for use with streamed audio.

Options:
Default values are shown in parenthesis.
−t num (7)

The measurement level used to trigger activity detection. This might need to be changed depending on the noise level, signal level and other charactistics of the input audio.

−T num (0.25)

The time constant (in seconds) used to help ignore short bursts of sound.

−s num (1)

The amount of audio (in seconds) to search for quieter/shorter bursts of audio to include prior to the detected trigger point.

−g num (0.25)

Allowed gap (in seconds) between quieter/shorter bursts of audio to include prior to the detected trigger point.

−p num (0)

The amount of audio (in seconds) to preserve before the trigger point and any found quieter/shorter bursts.

Advanced Options:

These allow fine tuning of the algorithm’s internal parameters.

−b num

The algorithm (internally) uses adaptive noise estimation/reduction in order to detect the start of the wanted audio. This option sets the time for the initial noise estimate.

−N num

Time constant used by the adaptive noise estimator for when the noise level is increasing.

−n num

Time constant used by the adaptive noise estimator for when the noise level is decreasing.

−r num

Amount of noise reduction to use in the detection algorithm (e.g. 0, 0.5, ...).

−f num

Frequency of the algorithm’s processing/measurements.

−m num

Measurement duration; by default, twice the measurement period; i.e. with overlap.

−M num

Time constant used to smooth spectral measurements.

−h num

‘Brick-wall’ frequency of high-pass filter applied at the input to the detector algorithm.

−l num

‘Brick-wall’ frequency of low-pass filter applied at the input to the detector algorithm.

−H num

‘Brick-wall’ frequency of high-pass lifter used in the detector algorithm.

−L num

‘Brick-wall’ frequency of low-pass lifter used in the detector algorithm.

See also the silence effect..]],
  },  
  
  
   {
    name = "SoX: Vol (+3db)",
    cmd = [[sox @in @out vol 3db]],
    desc = [[Apply an amplification or an attenuation to the audio signal. Unlike the −v option (which is used for balancing multiple input files as they enter the SoX effects processing chain), vol is an effect like any other so can be applied anywhere, and several times if necessary, during the processing chain. The amount to change the volume is given by gain which is interpreted, according to the given type, as follows: if type is amplitude (or is omitted), then gain is an amplitude (i.e. voltage or linear) ratio, if power, then a power (i.e. wattage or voltage-squared) ratio, and if dB, then a power change in dB. When type is amplitude or power, a gain of 1 leaves the volume unchanged, less than 1 decreases it, and greater than 1 increases it; a negative gain inverts the audio signal in addition to adjusting its volume. When type is dB, a gain of 0 leaves the volume unchanged, less than 0 decreases it, and greater than 0 increases it. See [4] for a detailed discussion on electrical (and hence audio signal) voltage and power ratios. Beware of Clipping when the increasing the volume. The gain and the type parameters can be concatenated if desired, e.g. vol 10dB. An optional limitergain value can be specified and should be a value much less than 1 (e.g. 0.05 or 0.02) and is used only on peaks to prevent clipping. Not specifying this parameter will cause no limiter to be used. In verbose mode, this effect will display the percentage of the audio that needed to be limited. See also gain for a volume-changing effect with different capabilities, and compand for a dynamic-range compression/expansion/limiting effect.]],
  },
  
     {
    name = "SoX: Vol (-3db)",
    cmd = [[sox @in @out vol -3db]],
    desc = [[Apply an amplification or an attenuation to the audio signal. Unlike the −v option (which is used for balancing multiple input files as they enter the SoX effects processing chain), vol is an effect like any other so can be applied anywhere, and several times if necessary, during the processing chain. The amount to change the volume is given by gain which is interpreted, according to the given type, as follows: if type is amplitude (or is omitted), then gain is an amplitude (i.e. voltage or linear) ratio, if power, then a power (i.e. wattage or voltage-squared) ratio, and if dB, then a power change in dB. When type is amplitude or power, a gain of 1 leaves the volume unchanged, less than 1 decreases it, and greater than 1 increases it; a negative gain inverts the audio signal in addition to adjusting its volume. When type is dB, a gain of 0 leaves the volume unchanged, less than 0 decreases it, and greater than 0 increases it. See [4] for a detailed discussion on electrical (and hence audio signal) voltage and power ratios. Beware of Clipping when the increasing the volume. The gain and the type parameters can be concatenated if desired, e.g. vol 10dB. An optional limitergain value can be specified and should be a value much less than 1 (e.g. 0.05 or 0.02) and is used only on peaks to prevent clipping. Not specifying this parameter will cause no limiter to be used. In verbose mode, this effect will display the percentage of the audio that needed to be limited. See also gain for a volume-changing effect with different capabilities, and compand for a dynamic-range compression/expansion/limiting effect.]],
  },

  {
    name = "SoX: Earwax",
    cmd = [[sox @in @out earwax]],
    desc = [[Makes audio easier to listen to on headphones. Adds ‘cues’ to 44.1kHz stereo (i.e. audio CD format) audio so that when listened to on headphones the stereo image is moved from inside your head (standard for headphones) to outside and in front of the listener (standard for speakers).]],
  },

}
